package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`6$```````````(`*``!````L)D``#0````0U0```@```#0`(``'
M`"@`&@`9``8````T````-(```#2```#@````X`````4````$`````P```!0!
M```4@0``%($``!,````3````!`````$````!``````````"`````@```:,\`
M`&C/```%`````(````$`````T````-`!``#0`0!P`@``I!(```8`````@```
M`@```!30```4T`$`%-`!`/````#P````!@````0````$````*`$``"B!```H
M@0``(````"`````$````!````%'E=&0```````````````````````````<`
M```$````+VQI8B]L9"UL:6YU>"YS;RXR```$````$`````$```!'3E4`````
M``(````&````#````&$```!V````$0``````````````8P````````!M````
M;```````````````40```%P```!4````<`````<````P`````````$H```!R
M`````P```#8```!F````&@````@```!!```````````````^````6@```&L`
M````````6P```!8```!N````*@```$\`````````<0```',````$````=0``
M```````O`````````&0`````````90```%<```````````````L````\````
M`````%4``````````````$`````.````8````&H``````````````!T`````
M````70``````````````-0`````````L````20```!(```!+````/0```$8`
M``````````````H````I````6````%\```!T````5@```$X```!$````$P``
M`````````````````$,```!>`````````&<````9````8@```%D````[````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````-````````````
M````````````````````````%0``````````````%P`````````8````````
M```````?`````````"$```````````````D`````````!0```"(````>````
M```````````<```````````````F````+0`````````````````````````T
M``````````$`````````-P`````````@```````````````&````&P```!``
M```````````````````````````````````K`````````#H`````````)P``
M`#@````/`````````"4```!(````.0```!0````R`````````%(````C````
M,P```"0``````````````"@```!,````/P```$(``````````````&$````Q
M````````````````````10```%````!-````+@```$<`````````:````&D`
M``````````````(```!3````;P````P`````````````````````````"@$`
M`$S2`0``````(``5`'@#```(E@``A`(``!(```""!```:*,``!P````2``P`
M0@,``!26```P````$@```),$```@IP``@````!(`#``1````()8```@````2
M````A0,``"R6``!(````$@```&H#```XE@``$````!(````H````1)8``"@`
M```2````H`0``)3P```$````$@`,``X!``"PF0```````!(`#``R````4)8`
M`#P%```2````/0```%R6``!,````$@```%```````````````"````!?````
M```````````@````<`,``'26``#,`@``$@```',```"`E@``$````!(````E
M!```C)8``$`````2````AP```)B6```0````$@```)D```"DE@``"````!(`
M``"J!```7/$````````2``T`L`0```SE``#$!@``$@`,`%L#``"PE@``S```
M`!(````K`P``O)8``'@!```2````Q@0``"2K``"8````$@`,`-0$```LH@``
M/`$``!(`#``%`P``R)8``'0````2````I@```-26```4!```$@```*\```#@
ME@``<`,``!(```"]````[)8``$`````2````H0,``/B6``"(````$@```.H$
M``"@IP``U`$``!(`#`#V!```A-0``&0````2``P`S0````27``!(`0``$@``
M`!$%``"TX```H````!(`#``)!```$)<``#`"```2````Y`(``!R7``"<````
M$@````T#```HEP``<````!(````=!0``:-(!``0````1`!4`VP```#27``"T
M`0``$@```'(%``"L]```N%H``!$`#@`<`P``:/$```0````1``X`Y@```$"7
M```<````$@```"T```!,EP``/`$``!(```#Z````6)<``.`"```2````+P0`
M`&27``!`````$@```/L#``!PEP``$````!(````(`0``3-(!```````0`!4`
M%0$``'R7```0````$@```%L$``!PT@$``````!``\?^\`P``B)<``,`````2
M````)P$``)27``"4````$@```,0#``"@EP``4````!(````U`0``K)<``$`&
M```2````10$``+B7``!,````$@```%8!``#$EP``"`$``!(```!G`0``T)<`
M`)`%```2````Z0,``-R7``!4`0``$@```+4#``#HEP``G`(``!(```#B`P``
M])<```0$```2````F@,```"8``!@````$@```&,#```,F```$````!(````(
M!0``&)@``'`!```2````+`4``,":``!8````$@`,`'8!```DF```8`$``!(`
M``!U!```I.(!```````0`/'_-`4``)CP``!H````$@`,`&D$``"DX@$`````
M`!``\?_2`P``,)@```@````2````'00``'#2`0`$````(0`6`(4!```\F```
MW`(``!(```!2`P``2)@``'0````2````^`(``%28``!P````$@```),!``!@
MF```,`\``!(```"H`P``;)@``$`!```2````3P0``'#2`0``````$`#Q_P\"
M``!XF```4`(``!(```"A`0``A)@``,P````2````:@0``*3B`0``````$`#Q
M_Z\#``"0F```$````!(````<!```<-(!``0````A`!8`DP,``)R8``"0````
M$@```*T!``"HF```$````!(```"^`0``M)@```@````2````V0,``,"8```0
M````$@```/,#``#,F```K`(``!(```!$!0``G.0``'`````2``P`T`$``-B8
M``!`````$@```.4!``#DF```$````!(```!]!```I.(!```````0`/'_8`4`
M`##?``"$`0``$@`,``,"``#PF```6````!(````6`@``_)@``)`````2````
M;04``&32`0`$````$0`5`!L$``!PT@$`!````!$`%@!^`P``")D``"`!```2
M````2@,``!29```8`0``$@```/X"```@F0``[````!(````C`@``+)D```@`
M```2````-0(``'32`0`3````$0`6`'P%``!8U@``V`@``!(`#`!(!```<-(!
M```````0`/'_1`(``#B9``#<`@``$@```(D%``#HU```<`$``!(`#`";!0``
MA*,``)P#```2``P`3P(``$29``!H````$@```(P#``!0F0``,````!(```!>
M`@``7)D``!P````2````<`(``&B9```0````$@````($``!TF0``-````!(`
M``"%`@``@)D``!`````2````/0,``(R9`````0``$@```*@%``!TJ0``L`$`
M`!(`#``6!```7.P```P$```2``P`+@4``."5````````$@`*`)8"``"8F0``
M7````!(```"M`@``I)D``(`'```2`````&QI8G!E<FPN<V\N-2XQ,`!097)L
M7TEC=7)S=&%C:VEN9F]?<'1R`'!E<FQ?9G)E90!P97)L7W!A<G-E`%!E<FQ?
M871F;W)K7W5N;&]C:P!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S
M<V5S`%!E<FQ?265V86Q?<F]O=%]P='(`4&5R;%]):6Y?979A;%]P='(`4&5R
M;%]);W!?<'1R`'!E<FQ?<G5N`%!E<FQ?879?<VAI9G0`4&5R;%]G=E]F971C
M:'!V`%!E<FQ?<W9?<V5T<'8`<&5R;%]A;&QO8P!097)L7T=D;U]U;F1U;7!?
M<'1R`%!E<FQ?9&]U;G=I;F0`7U]D871A7W-T87)T`%!E<FQ?271A:6YT961?
M<'1R`%!E<FQ?<WES7W1E<FT`8F]O=%]$>6YA3&]A9&5R`%!E<FQ?871F;W)K
M7VQO8VL`4&5R;%]N97=84U]F;&%G<P!P97)L7V-O;G-T<G5C=`!097)L7W-V
M7W-E='!V;@!097)L7V%V7V9E=&-H`'!E<FQ?9&5S=')U8W0`4&5R;%]M9U]S
M970`4&5R;%])<&%R<V5R7W!T<@!097)L7TES=&%T8G5F7W!T<@!097)L7V-R
M;V%K7VYO8V]N=&5X=`!097)L7TEP97)L7V1E<W1R=6-T7VQE=F5L7W!T<@!0
M97)L7W-A9F5S>7-M86QL;V,`4&5R;%]N97=35G!V`%!E<FQ?271O<%]E;G9?
M<'1R`%!,7VUE;6]R>5]W<F%P`%!E<FQ?;F5W6%,`4&5R;%]S>7-?:6YI=#,`
M4&5R;%]'=&AR7VME>5]P='(`4&5R;%])97AI=%]F;&%G<U]P='(`4&5R;%])
M8V]M<&-V7W!T<@!097)L7W-A=F5?9&5S=')U8W1O<E]X`%!E<FQ?<W9?,G!V
M7V9L86=S`&QI8F1L+G-O+C(`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!P
M=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&]P96XV-`!L<V5E:S8T`')E860`
M;&EB8RYS;RXV`%])3U]S=&1I;E]U<V5D`%]?<F5G:7-T97)?871F;W)K`&5X
M:70`<W!R:6YT9@!S=')N8VUP`&-L;W-E9&ER`'-T<FYC<'D`=6YL:6YK`&UK
M9&ER`')E86QL;V,`86)O<G0`;65M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K
M`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`&UE;6-P>0!O<&5N9&ER`%]?
M8W1Y<&5?8E]L;V,`9V5T=6ED`')E861L:6YK`&5X96-V<`!R96%D9&ER-C0`
M;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV
M:7)O;@!?7WAS=&%T-C0`7U]L>'-T870V-`!L:6)C<GEP="YS;RXQ`%]E9&%T
M80!?7V)S<U]S=&%R=`!?7V)S<U]S=&%R=%]?`%]?8G-S7V5N9%]?`%]?96YD
M7U\`7V5N9`!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?
M8W-U7V9I;FD`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`
M<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M
M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'-I>F5?;&]A9%]M95\R`'AS
M7VEN:70`7U]L:6)C7V-S=5]I;FET`%A37TEN=&5R;F%L<U]005)?0TQ%05)3
M5$%#2P!P87)?<FUT;7!D:7(`;F%M95]L;V%D7VUE7S(`<&%R7VUK=&UP9&ER
M`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P87)?:6YI=%]E;G8`
M1TQ)0D-?,BXP`$=,24)#7S(N,@!'3$E"0U\R+C,`1TQ)0D-?,BXS+C(`````
M`0`"``$``@`!`````@`"`````0`!`````````````@````,```````$``0`"
M``0``0`!``4``````````@`!``$````!``(`!@`&``$````!``$````"````
M`P`"``$````!``(````'`````````````P`"``(``@`"``(``0````$``0`!
M``(``@````(`!@````(``0`"`````0`"``(``@```````@`"``$```````$`
M`0```````0`"``(``@`%```````!``$````!``$````"```````"`````@`!
M``$``0```````0`"`-0"```0````,````!!I:0T```8`M04``!`````2:6D-
M```%`+\%`````````0`$`!(#```0`````````!-I:0T```<`R04``!````!R
M&6D)```$`-,%```0````$FEI#0```P"_!0``$````!!I:0T```(`M04`````
M``!(T@$`%0X``'#2`0`47P``=-(!`!1D```0T0$`%@(``!31`0`6!```&-$!
M`!8&```<T0$`%@<``"#1`0`6"```)-$!`!8)```HT0$`%@P``"S1`0`6#0``
M,-$!`!8.```TT0$`%A```#C1`0`6$0``/-$!`!82``!`T0$`%A,``$31`0`6
M%```2-$!`!87``!,T0$`%A@``%#1`0`6&P``5-$!`!8<``!8T0$`%AT``%S1
M`0`6'@``8-$!`!8?``!DT0$`%B(``&C1`0`6)```;-$!`!8E``!PT0$`%B8`
M`'31`0`6*```>-$!`!8K``!\T0$`%BP``(#1`0`6+0``A-$!`!8N``"(T0$`
M%B\``(S1`0`6,0``D-$!`!8S``"4T0$`%C0``)C1`0`6-0``G-$!`!8V``"@
MT0$`%C<``*31`0`6.```J-$!`!8Y``"LT0$`%CH``+#1`0`6.P``M-$!`!8\
M``"XT0$`%CT``+S1`0`6/@``P-$!`!8_``#$T0$`%D$``,C1`0`610``S-$!
M`!9'``#0T0$`%D@``-31`0`620``V-$!`!9*``#<T0$`%DL``.#1`0`630``
MY-$!`!9.``#HT0$`%E```.S1`0`64@``\-$!`!93``#TT0$`%E0``/C1`0`6
M50``_-$!`!96````T@$`%E@```32`0`660``"-(!`!9<```,T@$`%ET``!#2
M`0`68```%-(!`!9A```8T@$`%F(``!S2`0`68P``(-(!`!9G```DT@$`%FH`
M`"C2`0`6:P``+-(!`!9L```PT@$`%FT``#32`0`6;@``.-(!`!9O```\T@$`
M%G```$#2`0`6=```1-(!`!9U```$X"WE_P``ZR4!`.O+%@#K!/"=Y`3@+>4$
MX)_E#N"/X`CPON4`.P$``,:/XA/*C.(`^[SE`,:/XA/*C.+X^KSE`,:/XA/*
MC.+P^KSE`,:/XA/*C.+H^KSE`,:/XA/*C.+@^KSE`,:/XA/*C.+8^KSE`,:/
MXA/*C.+0^KSE`,:/XA/*C.+(^KSE`,:/XA/*C.+`^KSE`,:/XA/*C.*X^KSE
M`,:/XA/*C.*P^KSE`,:/XA/*C.*H^KSE`,:/XA/*C.*@^KSE`,:/XA/*C.*8
M^KSE`,:/XA/*C.*0^KSE`,:/XA/*C.*(^KSE`,:/XA/*C.*`^KSE`,:/XA/*
MC.)X^KSE`,:/XA/*C.)P^KSE`,:/XA/*C.)H^KSE`,:/XA/*C.)@^KSE`,:/
MXA/*C.)8^KSE`,:/XA/*C.)0^KSE`,:/XA/*C.)(^KSE`,:/XA/*C.)`^KSE
M`,:/XA/*C.(X^KSE`,:/XA/*C.(P^KSE`,:/XA/*C.(H^KSE`,:/XA/*C.(@
M^KSE`,:/XA/*C.(8^KSE`,:/XA/*C.(0^KSE`,:/XA/*C.((^KSE`,:/XA/*
MC.(`^KSE`,:/XA/*C.+X^;SE`,:/XA/*C.+P^;SE`,:/XA/*C.+H^;SE`,:/
MXA/*C.+@^;SE`,:/XA/*C.+8^;SE`,:/XA/*C.+0^;SE`,:/XA/*C.+(^;SE
M`,:/XA/*C.+`^;SE`,:/XA/*C.*X^;SE`,:/XA/*C.*P^;SE`,:/XA/*C.*H
M^;SE`,:/XA/*C.*@^;SE`,:/XA/*C.*8^;SE`,:/XA/*C.*0^;SE`,:/XA/*
MC.*(^;SE`,:/XA/*C.*`^;SE`,:/XA/*C.)X^;SE`,:/XA/*C.)P^;SE`,:/
MXA/*C.)H^;SE`,:/XA/*C.)@^;SE`,:/XA/*C.)8^;SE`,:/XA/*C.)0^;SE
M`,:/XA/*C.)(^;SE`,:/XA/*C.)`^;SE`,:/XA/*C.(X^;SE`,:/XA/*C.(P
M^;SE`,:/XA/*C.(H^;SE`,:/XA/*C.(@^;SE`,:/XA/*C.(8^;SE`,:/XA/*
MC.(0^;SE`,:/XA/*C.((^;SE`,:/XA/*C.(`^;SE`,:/XA/*C.+X^+SE`,:/
MXA/*C.+P^+SE`,:/XA/*C.+H^+SE`,:/XA/*C.+@^+SE`,:/XA/*C.+8^+SE
M`,:/XA/*C.+0^+SE`,:/XA/*C.+(^+SE`,:/XA/*C.+`^+SE`,:/XA/*C.*X
M^+SE`,:/XA/*C.*P^+SE`,:/XA/*C.*H^+SE`,:/XA/*C.*@^+SE`,:/XA/*
MC.*8^+SE),"?Y0"PH.,$$)WD#2"@X00@+>4$`"WE$`"?Y1`PG^4$P"WE3?__
MZPK__^N4\```7.P``)CP```4,)_E%""?Y0,PC^`"$)/G``!1XP[PH`$8___J
M##<!`$0!``#P0"WI5'"?Y0`PU^4``%/C\("]&$A@G^5(,)_E2$"?Y0,P9N!#
M,:#A`""4Y0%00^(%`%+A!@``*@$P@N(`,(3E#^"@X0/QEN<`()3E!0!2X?C_
M_SH!,*#C`##'Y?"`O>B(T@$`"-`!``S0`0",T@$`!.`MY03PG>0D`)_E`#"0
MY0``4^,$X"WE!/"=!!0PG^4``%/C!/"=!`_@H.$#\*#A!/"=Y!#0`0``````
M!.`MY03PG>0-P*#A`-@MZ02P3.($T$WB-#"?Y1`P"^4``*#CGO__ZP`PH.$`
M,)/E`P"@X0K__^L`,*#A`P"@X1`0G^40()_E$#`;Y8O__^L(J)WH;/$``'CQ
M``"LEP``#<"@X0#8+>D$L$SB`=I-X@S03>(!.N#C!S!#X@P`2^(#$(#G`3K@
MXPLP0^(,$$OB`R"!YP$Z2^(,,$/B!#!#XBP!G^4#$*#A_RZ@XP\@@N)4___K
M`#"@X1`P"^40,!OE``!3XPP``-H0,!OE`2!#X@$ZX.,#,$/B#,!+X@,PC.`"
M,(/@`##3Y0``4^,"```:$#`;Y0$P0^(0,`OE$#`;Y0``4^,>``#:$"`;Y0$Z
M2^(,,$/B!#!#X@,`H.$O$*#C2O__ZP`PH.$``%/C%```"@``H.-:___K`#"@
MX0`PD^4#`*#AQO[_ZP`PH.$#$*#A$,`;Y0$JX.,'($+B`3I+X@PP0^($,$/B
M`0"@X0S@2^("$)[G`R"@X0PPH.'Z_O_K$0``Z@``H.-%___K`#"@X0`PD^4#
M`*#AL?[_ZP`PH.$#$*#A`2K@XP<@0N(!.N#C"S!#X@$`H.$,P$OB`A"<YPS@
M2^(#()[GG_[_ZPS02^(`J)WHE/$```W`H.$`V"WI!+!,XAS03>(H``OE$!`+
MY2@@&^4``%+C`P``"A@QG^4`,)/E``!3XP(``!H`,*#C)#`+Y3P``.HH(!OE
M'"`+Y0(``.H<,!OE`3"#XAPP"^4<(!OE`##2Y0``4^,#```*'"`;Y0`PTN4]
M`%/C]/__&APP&^4H(!OE`S!BX"`P"^6T,)_E`#"3Y1@P"^4>``#J(#`;Y10`
M&^4H$!OE`R"@X?7^_^L`,*#A``!3XQ,``!H@,!OE%"`;Y0,P@N``,-/E/0!3
MXPT``!H8(!OE:#"?Y0`PD^4",&/@0S&@X0,@H.$0,!OE`""#Y2`P&^4!,(/B
M%"`;Y0,P@N`D,`OE"@``ZA@P&^4$,(/B&#`+Y1@@&^4`()+E%"`+Y10P&^4`
M`%/CVO__&@`@H.,D(`OE)#`;Y0,`H.$,T$OB`*B=Z'#2`0`-P*#A`-@MZ02P
M3.((T$WB%``+Y1`P2^(4`!OE`Q"@X:3__^L`,*#A`P"@X0S02^(`J)WH#<"@
MX1#8+>D$L$SB(-!-XAP`"^4P$`OE,!`;Y0`PT>4]`%/C`@``&C`@&^4!((+B
M,"`+Y3``&^5M_O_K`#"@X10P"^48,$OB'``;Y0,0H.&+___K`#"@X2@P"^4H
M,!OE``!3XQH```HH`!OE8/[_ZP`@H.$4,!OE`P!2X6```#HP$!OE`##1Y2@@
M&^4`,,+E*!`;Y0`PT>4``%/C`#"@`P$PH!/_,`/B*"`;Y0$@@N(H(`OE,!`;
MY0$0@>(P$`OE``!3X^W__QH`(*#C+"`+Y:D``.JP,I_E`#"3Y2`P"^4`,*#C
M)#`+Y04``.H@$!OE!!"!XB`0"^4D(!OE`2""XB0@"^4@$!OE`#"1Y0``4^/U
M__\:=#*?Y0`PD^4``%/C$@``"F`RG^4`()/E)!`;Y0(P@>(#,:#A`@"@X0,0
MH.'(_?_K`#"@X0,@H.$X,I_E`""#Y3`RG^4`,)/E``!3XQT``!H`(.#C+"`+
MY8(``.H8(I_E`3"@XP`P@N4D$!OE`C"!X@,QH.$#`*#A-O[_ZP`PH.$@,`OE
M("`;Y0``4N,"```:`##@XRPP"^5R``#JU#&?Y0`@D^4D,!OE`S&@X2``&^4"
M$*#A`R"@X3O^_^NT,9_E(!`;Y0`0@^6H,9_E`""3Y20P&^4!,(/B`S&@X0,@
M@N``,*#C`#""Y20P&^48,`OE'"`;Y2@@"^4"``#J*#`;Y0$P@^(H,`OE*!`;
MY0`PT>4``%/C`P``"B@@&^4`,-+E/0!3X_3__QI(,9_E`""3Y1@P&^4#,:#A
M`T""X"@@&^4<,!OE`C!CX`,@H.$4,!OE`S""X`(P@^(#`*#A_?W_ZP`PH.$`
M,(3E`#"4Y0``4^,"```:`##@XRPP"^4Y``#J\#"?Y0`@D^48,!OE`S&@X0,P
M@N``,)/E*#`+Y0(``.HH$!OE`1"!XB@0"^4<,!OE`##3Y2@@&^4`,,+E*!`;
MY0`PT>4``%/C`#"@`P$PH!/_(`/B'#`;Y0$P@^(<,`OE`3`BXO\P`^(``%/C
M`P``&B@@&^4`,-+E/0!3X^?__QH],*#C*!`;Y0`PP>4H(!OE`2""XB@@"^4P
M$!OE`##1Y2@@&^4`,,+E*!`;Y0`PT>4``%/C`#"@`P$PH!/_,`/B*"`;Y0$@
M@N(H(`OE,!`;Y0$0@>(P$`OE``!3X^W__QH`(*#C+"`+Y2PP&^4#`*#A$-!+
MXA"HG>APT@$`D-(!``W`H.$`V"WI!+!,X@S03>(4``OE$@``ZF@PG^4`()/E
M$#`;Y0,QH.$#((+@&"`+Y1@@&^4$,(+B`#"3Y1@@&^4`,(+E&"`;Y0`PDN4`
M`%/C`P``"A@P&^4$,(/B&#`+Y?+__^H0,$OB%``;Y0,0H.&>_O_K`#"@X0``
M4^/E__\:#-!+X@"HG>APT@$`#<"@X0#8+>D$L$SB`MI-XA#03>(`,*#C%#`+
MY??\_^L`(*#A`3I+X@PP0^(),$/B`P"@X?@0G^7X,)_EZ?S_ZP`PH.$0,`OE
M$#`;Y0``4^,#``"J`#"@XP(J2^(<,`+E+@``Z@$J2^(,($+B"2!"X@(Z2^(,
M,$/B"C!#X@(`H.$#$*#A`2J@XX']_^L`,*#A$#`+Y1`P&^4``%/C`P``J@`P
MH.,"*DOB'#`"Y1L``.H0,!OE`3"#X@,`H.%B_?_K`#"@X10P"^44,!OE``!3
MXP,``!H`,*#C`BI+XAPP`N4.``#J$"`;Y0(Z2^(,,$/B"C!#XA0`&^4#$*#A
M+OW_ZQ`@&^44,!OE`B"#X``PH.,`,,+E%#`;Y0(J2^(<,`+E`BI+XAPP$N4#
M`*#A#-!+X@"HG>BL\0``N/$```W`H.$`V"WI!+!,XJS__^L`,*#A`P"@X0"H
MG>@-P*#A`-@MZ02P3.(!VDWB(-!-X@$ZX.,3,$/B#"!+X@,`@N<!.N#C%S!#
MX@P@2^(#$(+G2`.?Y87^_^L`,*#A$#`+Y3PSG^4`()/E`3K@XQ,P0^(,$$OB
M`P"1YP(0H.$@_?_K`#"@X0``4^,,```*`3K@XQ,P0^(,`Y_E#"!+X@,0DN=_
M_O_K`3K@XQ,P0^(,$$OB`R"1YP$:2^(H(`'EL@``Z@$ZX.,3,$/B#!!+X@,`
MD>?P_/_K`#"@X1@P"^7(,I_E`""3Y0$ZX.,7,$/B#!!+X@,`D><"$*#A#?W_
MZP`PH.$<,`OED0``ZAPP&^4`,-/E``!3XP$``!J0,I_E'#`+Y1`P&^4``%/C
M#0``"A``&^4<$!OE-/W_ZP`PH.$``%/C!P``&F`RG^4`,)/E``"@XP,0H.'V
M_/_K`#"@X1PP"^5Z``#J'``;Y<K\_^L`,*#A%#`+Y0<``.H4,!OE`3!#XA0P
M"^44(!OE'#`;Y0(@@^``,*#C`##"Y10P&^4!($/B'#`;Y0(P@^``(-/E\#&?
MY0`PD^4`,-/E`P!2X>W__PH4,!OE`2"#XA@P&^4#((+@_SZ@XP\P@^(#`%+A
M#```V@$ZX.,3,$/BN`&?Y0P@2^(#$)+G*O[_ZP$ZX.,3,$/B#!!+X@,@D><!
M&DOB*"`!Y5T``.J(,9_E`,"3Y0$J2^(,($+B$"!"X@$ZX.,3,$/B#!!+X@,P
MD><`,(WE`@"@X6P1G^4<(!OE##"@X1;\_^L``*#CYOS_ZP`PH.$`,)/E`P"@
MX5+\_^L`,*#A`P"@X;7\_^L`(*#A`3I+X@PP0^(0,$/B`P"@X0(0H.'!$@#K
M`#"@X0``4^,E```:``"@X]/\_^L`,*#A`#"3Y0,`H.$__/_K`#"@X0,`H.&B
M_/_K`#"@X1`PD^4/.@/B`@E3XQ<``!H!.DOB##!#XA`P0^(#`*#A`1"@XT;\
M_^L`,*#A``!3XPX``!H!.DOB##!#XA`P0^*<`)_E`Q"@X>3]_^L!.DOB##!#
MXA`P0^(#`*#AL/S_ZP`PH.$!*DOB*#`"Y14``.IP,)_E`#"3Y0``H.,#$*#A
M>OS_ZP`PH.$<,`OE'#`;Y0``4^-J__\:`3K@XQ,P0^(\`)_E#"!+X@,0DN?+
M_?_K`3K@XQ,P0^(,$$OB`R"1YP$:2^(H(`'E`1I+XB@P$>4#`*#A#-!+X@"H
MG>B\\0``6-(!`,CQ``!<T@$`V/$``-SQ```-P*#A`-@MZ02P3.(,T$WB&``+
MY1@P&^44,`OE&#`;Y1`P"^4,``#J$#`;Y0`@T^5$,)_E`#"3Y0`PT^4#`%+A
M`@``&A`P&^4!,(/B%#`+Y1`P&^4!,(/B$#`+Y1`P&^4`,-/E``!3X^[__QH4
M,!OE`P"@X0S02^(`J)WH6-(!``W`H.$`V"WI!+!,X@S03>(0``OE$#`;Y0``
M4^,#```*$#`;Y0`PT^4``%/C!```&I`!G^5=_/_K`#"@X1@P"^5<``#J$``;
MY03\_^L`,*#A`2!#XA`P&^4",(/@%#`+Y0(``.H4(!OE`2!"XA0@"^40,!OE
M%"`;Y0,`4N$*``":%#`;Y0`@T^4\,9_E`#"3Y0`PT^4#`%+A\?__"@(``.H4
M(!OE`2!"XA0@"^40,!OE%"`;Y0,`4N$&``":%#`;Y0`@T^4`,9_E`#"3Y0`P
MT^4#`%+A\?__&A`P&^44(!OE`P!2X1(``!H4,!OE`"#3Y=0PG^4`,)/E`##3
MY0,`4N$$```:O`"?Y2C\_^L`,*#A&#`+Y2<``.JL,)_E`#"3Y0,`H.$A_/_K
M`#"@X1@P"^4@``#J%"`;Y0$@0N(4(`OE$#`;Y10@&^4#`%+A!@``FA0P&^4`
M(-/E;#"?Y0`PD^4`,-/E`P!2X?'__PH4(!OE$#`;Y0(P8^`",(/B`0I3XP(`
M`)H`(*#C&"`+Y0D``.H4(!OE$#`;Y0(P8^`!,(/B*`"?Y1`0&^4#(*#A5_O_
MZQ@PG^48,`OE&#`;Y0,`H.$,T$OB`*B=Z-CQ``!8T@$`E-(!``W`H.$`V"WI
M!+!,XBC03>)4,9_E,B!+XB+`H.,"`*#A`Q"@X0P@H.&1^__K/`&?Y?W]_^LX
M`9_E^_W_ZS0!G^7Y_?_K,`&?Y??]_^LL`9_E]?W_ZR@!G^7S_?_K)`&?Y?']
M_^L@`9_E[_W_ZQP!G^7M_?_K&`&?Y?G\_^L`,*#A$#`+Y1`P&^4``%/C`@``
M"N@`G^40$!OE_OS_Z_0`G^7O_/_K`#"@X1`P"^40,!OE``!3XP(```K<`)_E
M$!`;Y?3\_^O4`)_EY?S_ZP`PH.$0,`OE$#`;Y0``4^,#```*D`"?Y1`0&^7J
M_/_K&0``ZJP`G^7:_/_K`#"@X1`P"^40,!OE``!3XP,```IH`)_E$!`;Y=_\
M_^L.``#J,C!+XA$P@^(0,`OE$``;Y700G^4*(*#CF?O_ZP`PH.$``%/C!```
M&A`P&^4*,(/B*`"?Y0,0H.'/_/_K$`"?Y4@0G^7,_/_K#-!+X@"HG>BD\@``
MY/$``/3Q``"\\0```/(```SR```8\@``R/$``"3R```P\@``//(``%#R``!D
M\@``</(``(#R``"4\@``H/(```W`H.$`V"WI!+!,X@C03>)X,)_E`#"3Y0$`
M<^,6```:;`"?Y:+\_^L`,*#A$#`+Y1`P&^4``%/C"@``"A`P&^4`,-/E``!3
MXP8```H0,!OE`##3Y3``4^,"```*`2"@XQ0@"^4!``#J`#"@XQ0P"^48,)_E
M%"`;Y0`@@^4,,)_E`#"3Y0,`H.$,T$OB`*B=Z&#2`0``\@``#<"@X0#8+>D$
ML$SB6M]-XG0!"^5T,1OE'#"#XBPP"^4`,*#C,#`+Y1T``.HL,!OE`#"3Y2@P
M"^4L,!OE!#"#XBPP"^4P`!OE*#`;Y0,LH.$H,!OE`S2@X?\X`^(#((+A*#`;
MY2,TH.'_/`/B`R""X2@P&^4C/*#A`Q""X:<TH.-#.Z#A`"&@X0P`2^("((#@
M`S""X``0@^4P,!OE`3"#XC`P"^4P,!OE#P!3X][__]H0,*#C,#`+Y4(``.HP
M`!OE,#`;Y0,@0^*G-*#C0SN@X0(AH.$,$$OB`B"!X`,P@N``$)/E,#`;Y0@@
M0^*G-*#C0SN@X0(AH.$,P$OB`B",X`,P@N``,)/E`Q`AX#`P&^4.($/BIS2@
MXT,[H.$"(:#A#,!+X@(@C.`#,(+@`#"3Y0,0(>`P,!OE$"!#XJ<TH.-#.Z#A
M`B&@X0S`2^("((S@`S""X``PD^4#$"'@IS2@XT,[H.$`(:#A#`!+X@(@@.`#
M,(+@`!"#Y3``&^4P(!OEIS2@XT,[H.$"(:#A#!!+X@(@@>`#,(+@`#"3Y>,?
MH.&G-*#C0SN@X0`AH.$,P$OB`B",X`,P@N``$(/E,#`;Y0$P@^(P,`OE,#`;
MY4\`4^.Y___:=#$;Y0`PD^4D,`OE=#$;Y00PD^4@,`OE=#$;Y0@PD^4<,`OE
M=#$;Y0PPD^48,`OE=#$;Y1`PD^44,`OE%SY+XA`P"^4D,!OEXPV@X2`@&^4<
M,!OE`Q`"X"`P&^4#(.#A&#`;Y0,P`N`#,('A`R"`X!0P&^4#((+@$#`;Y0`P
MD^4#,(+@6C2#XH(X@^)Y/(/BF3"#XB@P"^40,!OE!#"#XA`P"^4@,!OE8S&@
MX2`P"^4H,!OEXPV@X20@&^4@,!OE`Q`"X"0P&^4#(.#A'#`;Y0,P`N`#,('A
M`R"`X!@P&^4#((+@$#`;Y0`PD^4#,(+@6C2#XH(X@^)Y/(/BF3"#XA0P"^40
M,!OE!#"#XA`P"^4D,!OE8S&@X20P"^44,!OEXPV@X2@@&^4D,!OE`Q`"X"@P
M&^4#(.#A(#`;Y0,P`N`#,('A`R"`X!PP&^4#((+@$#`;Y0`PD^4#,(+@6C2#
MXH(X@^)Y/(/BF3"#XA@P"^40,!OE!#"#XA`P"^4H,!OE8S&@X2@P"^48,!OE
MXPV@X10@&^4H,!OE`Q`"X!0P&^4#(.#A)#`;Y0,P`N`#,('A`R"`X"`P&^4#
M((+@$#`;Y0`PD^4#,(+@6C2#XH(X@^)Y/(/BF3"#XAPP"^40,!OE!#"#XA`P
M"^44,!OE8S&@X10P"^4<,!OEXPV@X1@@&^44,!OE`Q`"X!@P&^4#(.#A*#`;
MY0,P`N`#,('A`R"`X"0P&^4#((+@$#`;Y0`PD^4#,(+@6C2#XH(X@^)Y/(/B
MF3"#XB`P"^40,!OE!#"#XA`P"^48,!OE8S&@X1@P"^4@,!OEXPV@X1P@&^48
M,!OE`Q`"X!PP&^4#(.#A%#`;Y0,P`N`#,('A`R"`X"@P&^4#((+@$#`;Y0`P
MD^4#,(+@6C2#XH(X@^)Y/(/BF3"#XB0P"^40,!OE!#"#XA`P"^4<,!OE8S&@
MX1PP"^4D,!OEXPV@X2`@&^4<,!OE`Q`"X"`P&^4#(.#A&#`;Y0,P`N`#,('A
M`R"`X!0P&^4#((+@$#`;Y0`PD^4#,(+@6C2#XH(X@^)Y/(/BF3"#XB@P"^40
M,!OE!#"#XA`P"^4@,!OE8S&@X2`P"^4H,!OEXPV@X20@&^4@,!OE`Q`"X"0P
M&^4#(.#A'#`;Y0,P`N`#,('A`R"`X!@P&^4#((+@$#`;Y0`PD^4#,(+@6C2#
MXH(X@^)Y/(/BF3"#XA0P"^40,!OE!#"#XA`P"^4D,!OE8S&@X20P"^44,!OE
MXPV@X2@@&^4D,!OE`Q`"X"@P&^4#(.#A(#`;Y0,P`N`#,('A`R"`X!PP&^4#
M((+@$#`;Y0`PD^4#,(+@6C2#XH(X@^)Y/(/BF3"#XA@P"^40,!OE!#"#XA`P
M"^4H,!OE8S&@X2@P"^48,!OEXPV@X10@&^4H,!OE`Q`"X!0P&^4#(.#A)#`;
MY0,P`N`#,('A`R"`X"`P&^4#((+@$#`;Y0`PD^4#,(+@6C2#XH(X@^)Y/(/B
MF3"#XAPP"^40,!OE!#"#XA`P"^44,!OE8S&@X10P"^4<,!OEXPV@X1@@&^44
M,!OE`Q`"X!@P&^4#(.#A*#`;Y0,P`N`#,('A`R"`X"0P&^4#((+@$#`;Y0`P
MD^4#,(+@6C2#XH(X@^)Y/(/BF3"#XB`P"^40,!OE!#"#XA`P"^48,!OE8S&@
MX1@P"^4@,!OEXPV@X1P@&^48,!OE`Q`"X!PP&^4#(.#A%#`;Y0,P`N`#,('A
M`R"`X"@P&^4#((+@$#`;Y0`PD^4#,(+@6C2#XH(X@^)Y/(/BF3"#XB0P"^40
M,!OE!#"#XA`P"^4<,!OE8S&@X1PP"^4D,!OEXPV@X2`@&^4<,!OE`Q`"X"`P
M&^4#(.#A&#`;Y0,P`N`#,('A`R"`X!0P&^4#((+@$#`;Y0`PD^4#,(+@6C2#
MXH(X@^)Y/(/BF3"#XB@P"^40,!OE!#"#XA`P"^4@,!OE8S&@X2`P"^4H,!OE
MXPV@X20@&^4@,!OE`Q`"X"0P&^4#(.#A'#`;Y0,P`N`#,('A`R"`X!@P&^4#
M((+@$#`;Y0`PD^4#,(+@6C2#XH(X@^)Y/(/BF3"#XA0P"^40,!OE!#"#XA`P
M"^4D,!OE8S&@X20P"^44,!OEXPV@X2@@&^4D,!OE`Q`"X"@P&^4#(.#A(#`;
MY0,P`N`#,('A`R"`X!PP&^4#((+@$#`;Y0`PD^4#,(+@6C2#XH(X@^)Y/(/B
MF3"#XA@P"^40,!OE!#"#XA`P"^4H,!OE8S&@X2@P"^48,!OEXPV@X10@&^4H
M,!OE`Q`"X!0P&^4#(.#A)#`;Y0,P`N`#,('A`R"`X"`P&^4#((+@$#`;Y0`P
MD^4#,(+@6C2#XH(X@^)Y/(/BF3"#XAPP"^40,!OE!#"#XA`P"^44,!OE8S&@
MX10P"^4<,!OEXPV@X1@@&^44,!OE`Q`"X!@P&^4#(.#A*#`;Y0,P`N`#,('A
M`R"`X"0P&^4#((+@$#`;Y0`PD^4#,(+@6C2#XH(X@^)Y/(/BF3"#XB`P"^40
M,!OE!#"#XA`P"^48,!OE8S&@X1@P"^4@,!OEXPV@X1P@&^48,!OE`Q`"X!PP
M&^4#(.#A%#`;Y0,P`N`#,('A`R"`X"@P&^4#((+@$#`;Y0`PD^4#,(+@6C2#
MXH(X@^)Y/(/BF3"#XB0P"^40,!OE!#"#XA`P"^4<,!OE8S&@X1PP"^4D,!OE
MXPV@X2`@&^4<,!OE`Q`"X"`P&^4#(.#A&#`;Y0,P`N`#,('A`R"`X!0P&^4#
M((+@$#`;Y0`PD^4#,(+@6C2#XH(X@^)Y/(/BF3"#XB@P"^40,!OE!#"#XA`P
M"^4@,!OE8S&@X2`P"^4H,!OEXPV@X20@&^4@,!OE`Q`"X"0P&^4#(.#A'#`;
MY0,P`N`#,('A`R"`X!@P&^4#((+@$#`;Y0`PD^4#,(+@6C2#XH(X@^)Y/(/B
MF3"#XA0P"^40,!OE!#"#XA`P"^4D,!OE8S&@X20P"^44,!OEXQV@X2@@&^4D
M,!OE`R`BX"`P&^4#,"+@`R"!X!PP&^4#((+@$#`;Y0`PD^4#,(+@;S2#XB8X
M0^)1/4/B'S!#XA@P"^40,!OE!#"#XA`P"^4H,!OE8S&@X2@P"^48,!OEXQV@
MX10@&^4H,!OE`R`BX"0P&^4#,"+@`R"!X"`P&^4#((+@$#`;Y0`PD^4#,(+@
M;S2#XB8X0^)1/4/B'S!#XAPP"^40,!OE!#"#XA`P"^44,!OE8S&@X10P"^4<
M,!OEXQV@X1@@&^44,!OE`R`BX"@P&^4#,"+@`R"!X"0P&^4#((+@$#`;Y0`P
MD^4#,(+@;S2#XB8X0^)1/4/B'S!#XB`P"^40,!OE!#"#XA`P"^48,!OE8S&@
MX1@P"^4@,!OEXQV@X1P@&^48,!OE`R`BX!0P&^4#,"+@`R"!X"@P&^4#((+@
M$#`;Y0`PD^4#,(+@;S2#XB8X0^)1/4/B'S!#XB0P"^40,!OE!#"#XA`P"^4<
M,!OE8S&@X1PP"^4D,!OEXQV@X2`@&^4<,!OE`R`BX!@P&^4#,"+@`R"!X!0P
M&^4#((+@$#`;Y0`PD^4#,(+@;S2#XB8X0^)1/4/B'S!#XB@P"^40,!OE!#"#
MXA`P"^4@,!OE8S&@X2`P"^4H,!OEXQV@X20@&^4@,!OE`R`BX!PP&^4#,"+@
M`R"!X!@P&^4#((+@$#`;Y0`PD^4#,(+@;S2#XB8X0^)1/4/B'S!#XA0P"^40
M,!OE!#"#XA`P"^4D,!OE8S&@X20P"^44,!OEXQV@X2@@&^4D,!OE`R`BX"`P
M&^4#,"+@`R"!X!PP&^4#((+@$#`;Y0`PD^4#,(+@;S2#XB8X0^)1/4/B'S!#
MXA@P"^40,!OE!#"#XA`P"^4H,!OE8S&@X2@P"^48,!OEXQV@X10@&^4H,!OE
M`R`BX"0P&^4#,"+@`R"!X"`P&^4#((+@$#`;Y0`PD^4#,(+@;S2#XB8X0^)1
M/4/B'S!#XAPP"^40,!OE!#"#XA`P"^44,!OE8S&@X10P"^4<,!OEXQV@X1@@
M&^44,!OE`R`BX"@P&^4#,"+@`R"!X"0P&^4#((+@$#`;Y0`PD^4#,(+@;S2#
MXB8X0^)1/4/B'S!#XB`P"^40,!OE!#"#XA`P"^48,!OE8S&@X1@P"^4@,!OE
MXQV@X1P@&^48,!OE`R`BX!0P&^4#,"+@`R"!X"@P&^4#((+@$#`;Y0`PD^4#
M,(+@;S2#XB8X0^)1/4/B'S!#XB0P"^40,!OE!#"#XA`P"^4<,!OE8S&@X1PP
M"^4D,!OEXQV@X2`@&^4<,!OE`R`BX!@P&^4#,"+@`R"!X!0P&^4#((+@$#`;
MY0`PD^4#,(+@;S2#XB8X0^)1/4/B'S!#XB@P"^40,!OE!#"#XA`P"^4@,!OE
M8S&@X2`P"^4H,!OEXQV@X20@&^4@,!OE`R`BX!PP&^4#,"+@`R"!X!@P&^4#
M((+@$#`;Y0`PD^4#,(+@;S2#XB8X0^)1/4/B'S!#XA0P"^40,!OE!#"#XA`P
M"^4D,!OE8S&@X20P"^44,!OEXQV@X2@@&^4D,!OE`R`BX"`P&^4#,"+@`R"!
MX!PP&^4#((+@$#`;Y0`PD^4#,(+@;S2#XB8X0^)1/4/B'S!#XA@P"^40,!OE
M!#"#XA`P"^4H,!OE8S&@X2@P"^48,!OEXQV@X10@&^4H,!OE`R`BX"0P&^4#
M,"+@`R"!X"`P&^4#((+@$#`;Y0`PD^4#,(+@;S2#XB8X0^)1/4/B'S!#XAPP
M"^40,!OE!#"#XA`P"^44,!OE8S&@X10P"^4<,!OEXQV@X1@@&^44,!OE`R`B
MX"@P&^4#,"+@`R"!X"0P&^4#((+@$#`;Y0`PD^4#,(+@;S2#XB8X0^)1/4/B
M'S!#XB`P"^40,!OE!#"#XA`P"^48,!OE8S&@X1@P"^4@,!OEXQV@X1P@&^48
M,!OE`R`BX!0P&^4#,"+@`R"!X"@P&^4#((+@$#`;Y0`PD^4#,(+@;S2#XB8X
M0^)1/4/B'S!#XB0P"^40,!OE!#"#XA`P"^4<,!OE8S&@X1PP"^4D,!OEXQV@
MX2`@&^4<,!OE`R`BX!@P&^4#,"+@`R"!X!0P&^4#((+@$#`;Y0`PD^4#,(+@
M;S2#XB8X0^)1/4/B'S!#XB@P"^40,!OE!#"#XA`P"^4@,!OE8S&@X2`P"^4H
M,!OEXQV@X20@&^4@,!OE`R`BX!PP&^4#,"+@`R"!X!@P&^4#((+@$#`;Y0`P
MD^4#,(+@;S2#XB8X0^)1/4/B'S!#XA0P"^40,!OE!#"#XA`P"^4D,!OE8S&@
MX20P"^44,!OEXQV@X2@@&^4D,!OE`R`BX"`P&^4#,"+@`R"!X!PP&^4#((+@
M$#`;Y0`PD^4#,(+@;S2#XB8X0^)1/4/B'S!#XA@P"^40,!OE!#"#XA`P"^4H
M,!OE8S&@X2@P"^48,!OEXQV@X10@&^4H,!OE`R`BX"0P&^4#,"+@`R"!X"`P
M&^4#((+@$#`;Y0`PD^4#,(+@;S2#XB8X0^)1/4/B'S!#XAPP"^40,!OE!#"#
MXA`P"^44,!OE8S&@X10P"^4<,!OEXPV@X10@&^4H,!OE`R""X1@P&^4#$`+@
M%"`;Y2@P&^4#,`+@`S"!X0,@@.`D,!OE`R""X!`P&^4`,)/E`S""X`DR@^(Y
M-T/B0SQ#XB0P0^(@,`OE$#`;Y00P@^(0,`OE&#`;Y6,QH.$8,`OE(#`;Y>,-
MH.$8(!OE%#`;Y0,@@N$<,!OE`Q`"X!@@&^44,!OE`S`"X`,P@>$#((#@*#`;
MY0,@@N`0,!OE`#"3Y0,P@N`),H/B.3=#XD,\0^(D,$/B)#`+Y1`P&^4$,(/B
M$#`+Y1PP&^5C,:#A'#`+Y20P&^7C#:#A'"`;Y1@P&^4#((+A(#`;Y0,0`N`<
M(!OE&#`;Y0,P`N`#,('A`R"`X!0P&^4#((+@$#`;Y0`PD^4#,(+@"3*#XCDW
M0^)#/$/B)#!#XB@P"^40,!OE!#"#XA`P"^4@,!OE8S&@X2`P"^4H,!OEXPV@
MX2`@&^4<,!OE`R""X20P&^4#$`+@("`;Y1PP&^4#,`+@`S"!X0,@@.`8,!OE
M`R""X!`P&^4`,)/E`S""X`DR@^(Y-T/B0SQ#XB0P0^(4,`OE$#`;Y00P@^(0
M,`OE)#`;Y6,QH.$D,`OE%#`;Y>,-H.$D(!OE(#`;Y0,@@N$H,!OE`Q`"X"0@
M&^4@,!OE`S`"X`,P@>$#((#@'#`;Y0,@@N`0,!OE`#"3Y0,P@N`),H/B.3=#
MXD,\0^(D,$/B&#`+Y1`P&^4$,(/B$#`+Y2@P&^5C,:#A*#`+Y1@P&^7C#:#A
M*"`;Y20P&^4#((+A%#`;Y0,0`N`H(!OE)#`;Y0,P`N`#,('A`R"`X"`P&^4#
M((+@$#`;Y0`PD^4#,(+@"3*#XCDW0^)#/$/B)#!#XAPP"^40,!OE!#"#XA`P
M"^44,!OE8S&@X10P"^4<,!OEXPV@X10@&^4H,!OE`R""X1@P&^4#$`+@%"`;
MY2@P&^4#,`+@`S"!X0,@@.`D,!OE`R""X!`P&^4`,)/E`S""X`DR@^(Y-T/B
M0SQ#XB0P0^(@,`OE$#`;Y00P@^(0,`OE&#`;Y6,QH.$8,`OE(#`;Y>,-H.$8
M(!OE%#`;Y0,@@N$<,!OE`Q`"X!@@&^44,!OE`S`"X`,P@>$#((#@*#`;Y0,@
M@N`0,!OE`#"3Y0,P@N`),H/B.3=#XD,\0^(D,$/B)#`+Y1`P&^4$,(/B$#`+
MY1PP&^5C,:#A'#`+Y20P&^7C#:#A'"`;Y1@P&^4#((+A(#`;Y0,0`N`<(!OE
M&#`;Y0,P`N`#,('A`R"`X!0P&^4#((+@$#`;Y0`PD^4#,(+@"3*#XCDW0^)#
M/$/B)#!#XB@P"^40,!OE!#"#XA`P"^4@,!OE8S&@X2`P"^4H,!OEXPV@X2`@
M&^4<,!OE`R""X20P&^4#$`+@("`;Y1PP&^4#,`+@`S"!X0,@@.`8,!OE`R""
MX!`P&^4`,)/E`S""X`DR@^(Y-T/B0SQ#XB0P0^(4,`OE$#`;Y00P@^(0,`OE
M)#`;Y6,QH.$D,`OE%#`;Y>,-H.$D(!OE(#`;Y0,@@N$H,!OE`Q`"X"0@&^4@
M,!OE`S`"X`,P@>$#((#@'#`;Y0,@@N`0,!OE`#"3Y0,P@N`),H/B.3=#XD,\
M0^(D,$/B&#`+Y1`P&^4$,(/B$#`+Y2@P&^5C,:#A*#`+Y1@P&^7C#:#A*"`;
MY20P&^4#((+A%#`;Y0,0`N`H(!OE)#`;Y0,P`N`#,('A`R"`X"`P&^4#((+@
M$#`;Y0`PD^4#,(+@"3*#XCDW0^)#/$/B)#!#XAPP"^40,!OE!#"#XA`P"^44
M,!OE8S&@X10P"^4<,!OEXPV@X10@&^4H,!OE`R""X1@P&^4#$`+@%"`;Y2@P
M&^4#,`+@`S"!X0,@@.`D,!OE`R""X!`P&^4`,)/E`S""X`DR@^(Y-T/B0SQ#
MXB0P0^(@,`OE$#`;Y00P@^(0,`OE&#`;Y6,QH.$8,`OE(#`;Y>,-H.$8(!OE
M%#`;Y0,@@N$<,!OE`Q`"X!@@&^44,!OE`S`"X`,P@>$#((#@*#`;Y0,@@N`0
M,!OE`#"3Y0,P@N`),H/B.3=#XD,\0^(D,$/B)#`+Y1`P&^4$,(/B$#`+Y1PP
M&^5C,:#A'#`+Y20P&^7C#:#A'"`;Y1@P&^4#((+A(#`;Y0,0`N`<(!OE&#`;
MY0,P`N`#,('A`R"`X!0P&^4#((+@$#`;Y0`PD^4#,(+@"3*#XCDW0^)#/$/B
M)#!#XB@P"^40,!OE!#"#XA`P"^4@,!OE8S&@X2`P"^4H,!OEXPV@X2`@&^4<
M,!OE`R""X20P&^4#$`+@("`;Y1PP&^4#,`+@`S"!X0,@@.`8,!OE`R""X!`P
M&^4`,)/E`S""X`DR@^(Y-T/B0SQ#XB0P0^(4,`OE$#`;Y00P@^(0,`OE)#`;
MY6,QH.$D,`OE%#`;Y>,-H.$D(!OE(#`;Y0,@@N$H,!OE`Q`"X"0@&^4@,!OE
M`S`"X`,P@>$#((#@'#`;Y0,@@N`0,!OE`#"3Y0,P@N`),H/B.3=#XD,\0^(D
M,$/B&#`+Y1`P&^4$,(/B$#`+Y2@P&^5C,:#A*#`+Y1@P&^7C#:#A*"`;Y20P
M&^4#((+A%#`;Y0,0`N`H(!OE)#`;Y0,P`N`#,('A`R"`X"`P&^4#((+@$#`;
MY0`PD^4#,(+@"3*#XCDW0^)#/$/B)#!#XAPP"^40,!OE!#"#XA`P"^44,!OE
M8S&@X10P"^4<,!OEXPV@X10@&^4H,!OE`R""X1@P&^4#$`+@%"`;Y2@P&^4#
M,`+@`S"!X0,@@.`D,!OE`R""X!`P&^4`,)/E`S""X`DR@^(Y-T/B0SQ#XB0P
M0^(@,`OE$#`;Y00P@^(0,`OE&#`;Y6,QH.$8,`OE(#`;Y>,-H.$8(!OE%#`;
MY0,@@N$<,!OE`Q`"X!@@&^44,!OE`S`"X`,P@>$#((#@*#`;Y0,@@N`0,!OE
M`#"3Y0,P@N`),H/B.3=#XD,\0^(D,$/B)#`+Y1`P&^4$,(/B$#`+Y1PP&^5C
M,:#A'#`+Y20P&^7C':#A("`;Y1PP&^4#("+@&#`;Y0,P(N`#(('@%#`;Y0,@
M@N`0,!OE`#"3Y0,P@N#*-(/B8CB#XL$\@^+6,(/B*#`+Y1`P&^4$,(/B$#`+
MY2`P&^5C,:#A(#`+Y2@P&^7C':#A)"`;Y2`P&^4#("+@'#`;Y0,P(N`#(('@
M&#`;Y0,@@N`0,!OE`#"3Y0,P@N#*-(/B8CB#XL$\@^+6,(/B%#`+Y1`P&^4$
M,(/B$#`+Y20P&^5C,:#A)#`+Y10P&^7C':#A*"`;Y20P&^4#("+@(#`;Y0,P
M(N`#(('@'#`;Y0,@@N`0,!OE`#"3Y0,P@N#*-(/B8CB#XL$\@^+6,(/B&#`+
MY1`P&^4$,(/B$#`+Y2@P&^5C,:#A*#`+Y1@P&^7C':#A%"`;Y2@P&^4#("+@
M)#`;Y0,P(N`#(('@(#`;Y0,@@N`0,!OE`#"3Y0,P@N#*-(/B8CB#XL$\@^+6
M,(/B'#`+Y1`P&^4$,(/B$#`+Y10P&^5C,:#A%#`+Y1PP&^7C':#A&"`;Y10P
M&^4#("+@*#`;Y0,P(N`#(('@)#`;Y0,@@N`0,!OE`#"3Y0,P@N#*-(/B8CB#
MXL$\@^+6,(/B(#`+Y1`P&^4$,(/B$#`+Y1@P&^5C,:#A&#`+Y2`P&^7C':#A
M'"`;Y1@P&^4#("+@%#`;Y0,P(N`#(('@*#`;Y0,@@N`0,!OE`#"3Y0,P@N#*
M-(/B8CB#XL$\@^+6,(/B)#`+Y1`P&^4$,(/B$#`+Y1PP&^5C,:#A'#`+Y20P
M&^7C':#A("`;Y1PP&^4#("+@&#`;Y0,P(N`#(('@%#`;Y0,@@N`0,!OE`#"3
MY0,P@N#*-(/B8CB#XL$\@^+6,(/B*#`+Y1`P&^4$,(/B$#`+Y2`P&^5C,:#A
M(#`+Y2@P&^7C':#A)"`;Y2`P&^4#("+@'#`;Y0,P(N`#(('@&#`;Y0,@@N`0
M,!OE`#"3Y0,P@N#*-(/B8CB#XL$\@^+6,(/B%#`+Y1`P&^4$,(/B$#`+Y20P
M&^5C,:#A)#`+Y10P&^7C':#A*"`;Y20P&^4#("+@(#`;Y0,P(N`#(('@'#`;
MY0,@@N`0,!OE`#"3Y0,P@N#*-(/B8CB#XL$\@^+6,(/B&#`+Y1`P&^4$,(/B
M$#`+Y2@P&^5C,:#A*#`+Y1@P&^7C':#A%"`;Y2@P&^4#("+@)#`;Y0,P(N`#
M(('@(#`;Y0,@@N`0,!OE`#"3Y0,P@N#*-(/B8CB#XL$\@^+6,(/B'#`+Y1`P
M&^4$,(/B$#`+Y10P&^5C,:#A%#`+Y1PP&^7C':#A&"`;Y10P&^4#("+@*#`;
MY0,P(N`#(('@)#`;Y0,@@N`0,!OE`#"3Y0,P@N#*-(/B8CB#XL$\@^+6,(/B
M(#`+Y1`P&^4$,(/B$#`+Y1@P&^5C,:#A&#`+Y2`P&^7C':#A'"`;Y1@P&^4#
M("+@%#`;Y0,P(N`#(('@*#`;Y0,@@N`0,!OE`#"3Y0,P@N#*-(/B8CB#XL$\
M@^+6,(/B)#`+Y1`P&^4$,(/B$#`+Y1PP&^5C,:#A'#`+Y20P&^7C':#A("`;
MY1PP&^4#("+@&#`;Y0,P(N`#(('@%#`;Y0,@@N`0,!OE`#"3Y0,P@N#*-(/B
M8CB#XL$\@^+6,(/B*#`+Y1`P&^4$,(/B$#`+Y2`P&^5C,:#A(#`+Y2@P&^7C
M':#A)"`;Y2`P&^4#("+@'#`;Y0,P(N`#(('@&#`;Y0,@@N`0,!OE`#"3Y0,P
M@N#*-(/B8CB#XL$\@^+6,(/B%#`+Y1`P&^4$,(/B$#`+Y20P&^5C,:#A)#`+
MY10P&^7C':#A*"`;Y20P&^4#("+@(#`;Y0,P(N`#(('@'#`;Y0,@@N`0,!OE
M`#"3Y0,P@N#*-(/B8CB#XL$\@^+6,(/B&#`+Y1`P&^4$,(/B$#`+Y2@P&^5C
M,:#A*#`+Y1@P&^7C':#A%"`;Y2@P&^4#("+@)#`;Y0,P(N`#(('@(#`;Y0,@
M@N`0,!OE`#"3Y0,P@N#*-(/B8CB#XL$\@^+6,(/B'#`+Y1`P&^4$,(/B$#`+
MY10P&^5C,:#A%#`+Y1PP&^7C':#A&"`;Y10P&^4#("+@*#`;Y0,P(N`#(('@
M)#`;Y0,@@N`0,!OE`#"3Y0,P@N#*-(/B8CB#XL$\@^+6,(/B(#`+Y1`P&^4$
M,(/B$#`+Y1@P&^5C,:#A&#`+Y2`P&^7C':#A'"`;Y1@P&^4#("+@%#`;Y0,P
M(N`#(('@*#`;Y0,@@N`0,!OE`#"3Y0,P@N#*-(/B8CB#XL$\@^+6,(/B)#`+
MY1`P&^4$,(/B$#`+Y1PP&^5C,:#A'#`+Y20P&^7C':#A("`;Y1PP&^4#("+@
M&#`;Y0,P(N`#(('@%#`;Y0,@@N`0,!OE`#"3Y0,P@N#*-(/B8CB#XL$\@^+6
M,(/B*#`+Y1`P&^4$,(/B$#`+Y2`P&^5C,:#A(#`+Y2@P&^7C':#A)"`;Y2`P
M&^4#("+@'#`;Y0,P(N`#(('@&#`;Y0,@@N`0,!OE`#"3Y0,P@N#*-(/B8CB#
MXL$\@^+6,(/B%#`+Y1`P&^4$,(/B$#`+Y20P&^5C,:#A)#`+Y70Q&^4`()/E
M%#`;Y0,@@N!T,1OE`""#Y70Q&^4$()/E*#`;Y0,@@N!T,1OE!""#Y70Q&^4(
M()/E)#`;Y0,@@N!T,1OE"""#Y70Q&^4,()/E(#`;Y0,@@N!T,1OE#""#Y70Q
M&^40()/E'#`;Y0,@@N!T,1OE$""#Y0S02^(`J)WH#<"@X0#8+>D$L$SB!-!-
MXA``"^40(!OE6#"?Y0`P@N40(!OE4#"?Y00P@N40(!OE2#"?Y0@P@N40(!OE
M0#"?Y0PP@N40(!OE.#"?Y1`P@N40(!OE`#"@XQ0P@N40(!OE`#"@XQ@P@N40
M(!OE`#"@XUPP@N4(J)WH`2-%9XFKS>_^W+J8=E0R$/#ATL,-P*#A`-@MZ02P
M3.(4T$WB&``+Y1P0"^4@(`OE&#`;Y10@D^4@,!OE@S&@X0,P@N`0,`OE&#`;
MY10@D^40,!OE`P!2X00``)H8,!OE&#"3Y0$@@^(8,!OE&""#Y1@@&^40,!OE
M%#""Y1@P&^48()/E(#`;Y:,^H.$#((+@&#`;Y1@@@^48,!OE7#"3Y0``4^,U
M```*&#`;Y5PPD^5`,&/B%#`+Y10@&^4@,!OE`P!2X0$``-H@,!OE%#`+Y1@P
M&^4<((/B&#`;Y5PPD^4#,(+@%"`;Y0,`H.$<$!OE_?'_ZR`@&^44,!OE`C!C
MX"`P"^44(!OE'#`;Y0(P@^`<,`OE&#`;Y5P@D^44,!OE`R""X!@P&^5<((/E
M&#`;Y5PPD^5``%/C'```&A@`&^7>]O_K#0``ZA@P&^4<,(/B`P"@X1P0&^5`
M(*#CXO'_ZQPP&^5`,(/B'#`+Y2`P&^5`,$/B(#`+Y1@`&^7/]O_K(#`;Y3\`
M4^/N___*&#`;Y1PP@^(@(!OE`P"@X1P0&^71\?_K&"`;Y2`P&^5<,(+E#-!+
MX@"HG>@-P*#A`-@MZ02P3.((T$WB$``+Y100"^44`!OEN?;_ZQ0P&^4`,)/E
M(SR@X?\P`^(0(!OE`##"Y1`P&^4!((/B%#`;Y0`PD^4C.*#A_S`#X@`PPN40
M,!OE`B"#XA0P&^4`,)/E(S2@X?\P`^(`,,+E$#`;Y0,@@^(4,!OE`#"3Y?\P
M`^(`,,+E$#`;Y00@@^(4,!OE!#"3Y2,\H.'_,`/B`##"Y1`P&^4%((/B%#`;
MY00PD^4C.*#A_S`#X@`PPN40,!OE!B"#XA0P&^4$,)/E(S2@X?\P`^(`,,+E
M$#`;Y0<@@^(4,!OE!#"3Y?\P`^(`,,+E$#`;Y0@@@^(4,!OE"#"3Y2,\H.'_
M,`/B`##"Y1`P&^4)((/B%#`;Y0@PD^4C.*#A_S`#X@`PPN40,!OE"B"#XA0P
M&^4(,)/E(S2@X?\P`^(`,,+E$#`;Y0L@@^(4,!OE"#"3Y?\P`^(`,,+E$#`;
MY0P@@^(4,!OE##"3Y2,\H.'_,`/B`##"Y1`P&^4-((/B%#`;Y0PPD^4C.*#A
M_S`#X@`PPN40,!OE#B"#XA0P&^4,,)/E(S2@X?\P`^(`,,+E$#`;Y0\@@^(4
M,!OE##"3Y?\P`^(`,,+E$#`;Y1`@@^(4,!OE$#"3Y2,\H.'_,`/B`##"Y1`P
M&^41((/B%#`;Y1`PD^4C.*#A_S`#X@`PPN40,!OE$B"#XA0P&^40,)/E(S2@
MX?\P`^(`,,+E$#`;Y1,@@^(4,!OE$#"3Y?\P`^(`,,+E#-!+X@"HG>@-P*#A
M`-@MZ02P3.(4T$WB'``+Y2`0"^4@,!OE%#"3Y10P"^4@,!OE&#"3Y1`P"^44
M,!OEHS&@X3\P`^(8,`OE(#`;Y1P@@^(8,!OE`R""X'\PX.,`,,+E&#`;Y0$P
M@^(8,`OE&#`;Y3@`4^,2``#:(#`;Y1P@@^(8,!OE`R""X!@P&^5`,&/B`@"@
MX0`0H.,#(*#AVO#_ZR``&^4)]O_K(#`;Y1PP@^(#`*#A`!"@XS@@H./2\/_K
M"0``ZB`P&^4<((/B&#`;Y0,@@N`8,!OE.#!CX@(`H.$`$*#C`R"@X<?P_^L0
M,!OE(SR@X?\P`^(@(!OE5##"Y1`P&^4C.*#A_S`#XB`@&^55,,+E$#`;Y2,T
MH.'_,`/B("`;Y58PPN40,!OE_S`#XB`@&^57,,+E%#`;Y2,\H.'_,`/B("`;
MY5@PPN44,!OE(SB@X?\P`^(@(!OE63#"Y10P&^4C-*#A_S`#XB`@&^5:,,+E
M%#`;Y?\P`^(@(!OE6S#"Y1P`&^4@$!OE#?__ZPS02^(`J)WH#<"@X0#8+>D$
ML$SB#-!-X@`PH.,8,`OE`#"@XQ0P"^7A\/_K`#"@X1`P"^40,!OE``!3XP8`
M``H0`!OEU/#_ZP`PH.$4,`OE%#`;Y0`PD^48,`OE&#`;Y0,`H.$,T$OB`*B=
MZ`W`H.$0V"WI!+!,XC#03>(\``OE`#"@XR`P"^4`,*#C'#`+Y3@QG^4X0$OB
M`\"@X0\`O.@/`*3H`P"<Z`,`A.@`,*#C%#`+Y0`PH.,8,`OE-0``ZB``&^4D
M\O_K`#"@X1PP"^4<,!OE``!3XP,```H<,!OE`##3Y0``4^,#```:(``;Y3P0
M&^4E\O_K(P``ZAP`&^4\$!OEN?#_ZP`PH.$``%/C'0``&CP`&^69\/_K`$"@
MX:PPG^4`,)/E`P"@X93P_^L`,*#A`T"$X!P`&^60\/_K`#"@X0,PA.`",(/B
M`P"@X:GP_^L`,*#A%#`+Y7`PG^4`P)/E'#`;Y0`PC>44`!OE8!"?Y3P@&^4,
M,*#A!?#_ZR``&^44$!OE`/+_ZQ@P&^4!,(/B&#`+Y1@P&^4G(.#C`S&@X1`0
M2^(#,('@`C"#X``PD^4@,`OE(#`;Y0`PT^4``%/CO?__&A#02^(0J)WH$/,`
M`%S2`0#<\0``#<"@X1#8+>D$L$SB@=Q-XAS03>*!/.#C#S!#XA`02^(#`('G
M`#"@XT`P"^4`,*#C/#`+Y0`PH.,X,`OE6#B?Y5C`2^(/`)/H#P",Z$PXG^5P
MX$OB`\"@X0\`O.@/`*[H`P"<Z`,`CN@T.)_E?,!+X@<`D^@'`(SH*#B?Y30P
M"^4D.)_E,#`+Y0`PH.,L,`OE`#"@XR@P"^4`,*#C)#`+Y0`PH.,4,`OE``B?
MY;/Q_^L`,*#A.#`+Y3@P&^4``%/C"P``"C@P&^4`,-/E``!3XP<```HX`!OE
M;/__ZS@`&^6$\/_K`#"@X0(I2^(D,0+EY`$`ZDS__^L`,*#A*#`+Y2@P&^4`
M`%/C'P``&@`PH.-(,`OE#0``ZCP`&^67\?_K`#"@X3@P"^4X,!OE``!3XP,`
M``HX`!OE;O#_ZP`PH.$H,`OE2#`;Y0$P@^)(,`OE*#`;Y0``4^,+```:2#`;
MY6L@X.,#,:#A$`!+X@,P@.`",(/@`#"3Y3PP"^4\,!OE`##3Y0``4^/B__\:
M*#`;Y0``4^,"```:%#>?Y2@P"^49``#J*#`;Y40P"^42``#JY.__ZP`PH.$`
M()/E1#`;Y0`PT^6#,*#A`S""X``@T^4!,-/E`S2"X0@P`^(``%/C`@``&D0P
M&^5?(*#C`"##Y40P&^4!,(/B1#`+Y40P&^4`,-/E``!3X^C__QH`,*#C2#`+
MY3\``.H\`!OE5_'_ZP`PH.$X,`OE.#`;Y0``4^,U```*``"@XS'P_^L`,*#A
M`#"3Y0,`H.&=[__K`#"@X0,`H.$`\/_K`#"@X3@`&^4#$*#A$P8`ZP`PH.$`
M`%/C)0``&@``H.,A\/_K`#"@X0`PD^4#`*#AC>__ZP`PH.$#`*#A\.__ZP`P
MH.$0,)/E#SH#X@$)4^,-```*``"@XQ/P_^L`,*#A`#"3Y0,`H.%_[__K`#"@
MX0,`H.'B[__K`#"@X1`PD^4/.@/B"@I3XPD``!HX`!OE`A"@XXGO_^L`,*#A
M``!3XP,``!HX`!OE_.__ZP`PH.%`,`OE2#`;Y0$P@^)(,`OE0#`;Y0``4^,+
M```:2#`;Y5\@X.,#,:#A$!!+X@,P@>`",(/@`#"3Y3PP"^4\,!OE`##3Y0``
M4^.P__\:`#"@XT@P"^4X``#J``"@X^;O_^L`,*#A`#"3Y0,`H.%2[__K`#"@
MX0,`H.&U[__K`#"@X3@`&^4#$*#AR`4`ZP`PH.$``%/C)0``&@``H./6[__K
M`#"@X0`PD^4#`*#A0N__ZP`PH.$#`*#AI>__ZP`PH.$0,)/E#SH#X@$)4^,-
M```*``"@X\CO_^L`,*#A`#"3Y0,`H.$T[__K`#"@X0,`H.&7[__K`#"@X1`P
MD^4/.@/B"@I3XPD``!HX`!OE`A"@XS[O_^L`,*#A``!3XP,``!HX`!OEL>__
MZP`PH.%`,`OE2#`;Y0$P@^)(,`OE0#`;Y0``4^,+```:2#`;Y4<@X.,#,:#A
M$`!+X@,P@.`",(/@`#"3Y3@P"^4X,!OE`##3Y0``4^.W__\:0``;Y4?O_^L`
M0*#A-``;Y43O_^L`,*#A`T"$X"@`&^5`[__K`#"@X0-`A.`P`!OE/.__ZP`P
MH.$#,(3@`3N#XA0P"^44,!OE`P"@X5/O_^L`,*#A)#`+Y=@SG^4`P)/E-#`;
MY0`PC>4H,!OE!#"-Y20`&^7`$Y_E0"`;Y0PPH.&M[O_K)``;Y7L?H.,!$('B
MLN[_ZZ0#G^68\/_K`#"@X3@P"^6!/.#C#S!#XA`02^(#,)'G`$"3Y3@`&^5M
M[__K`#"@X00`H.$#$*#A]O'_ZP`PH.$L,`OE+#`;Y0``4^,%```:@3S@XP\P
M0^(0($OB`S"2YP`PD^4L,`OETO/_ZP`PH.$``%/CIP``&BP`&^4`$*#C2^__
MZP`PH.$@,`OE(#`;Y0``4^.?```*(``;Y1$0X.,`(.#C`C"@XZON_^L".4OB
M$#!#XO@P0^(@`!OE`Q"@X08@H..\[O_K`CG@X_<P0^(0`$OB`S#0YP``4^-&
M```:`CG@X_<P0^(!(*#C$!!+X@,P@>`",(/@`##3Y4,`4^,]```:`CG@X_<P
M0^("(*#C$`!+X@,P@.`",(/@`##3Y4$`4^,T```:`CG@X_<P0^(#(*#C$!!+
MX@,P@>`",(/@`##3Y4,`4^,K```:`CG@X_<P0^($(*#C$`!+X@,P@.`",(/@
M`##3Y4@`4^,B```:`CG@X_<P0^(%(*#C$!!+X@,P@>`",(/@`##3Y44`4^,9
M```:(``;Y3D0X.,`(.#C`C"@XVSN_^L".4OB$#!#XO@P0^(@`!OE`Q"@X2D@
MH.-][O_KV#&?Y0#`D^4".4OB$#!#XO@P0^(`,(WE,#`;Y00PC>4D`!OEP!&?
MY20@&^4,,*#A*^[_ZU4``.I"/TOB`P"@X4/\_^L'``#J0B]+X@(Y2^(0,$/B
M^#!#X@(`H.$#$*#A'"`;Y5W\_^L".4OB$#!#XO@P0^(@`!OE`Q"@X0(IH.-<
M[O_K`#"@X1PP"^4<,!OE``!3X^O__\H@`!OEH.[_ZX$\2^(0,$/B##!#XD(O
M2^(#`*#A`A"@X4']_^L`,*#C&#`+Y1$``.H8,!OE@S"@X:4@2^(#((+@&!`;
MY8$\X.,+,$/B$`!+X@,P@.`!,(/@`##3Y0(`H.'P$)_E`R"@X??M_^L8,!OE
M`3"#XA@P"^48,!OE$P!3X^K__]H`,*#C?3!+Y;0PG^4`P)/EI3!+X@`PC>4P
M,!OE!#"-Y20`&^6D$)_E)"`;Y0PPH.'D[?_K#@``ZI@`G^68$)_EWN__ZW@P
MG^4`0)/EX^W_ZP`PH.$`,(WE,#`;Y00PC>4D`!OE=!"?Y20@&^4$,*#AU.W_
MZT``G^4D$!OES^__ZR0`&^6$_?_K)"`;Y0(92^(D(0'E`@E+XB0Q$.4#`*#A
M$-!+XA"HG>B,\P``9/,``#SS``"<\P``#/,``+SQ``"D\P``6-(!`*SS``#P
M\@``N/,``,CS````\@``H/(``-#S```-P*#A$-@MZ02P3.)XT$WBA``+Y8@0
M"^4`,*#C&#`+Y80`&^4+[O_K`#"@X2`P"^4@,!OE``!3XTP```H]``#J'#`;
MY1,P@^(#`*#A)!&?Y7ON_^L`,*#A``!3XS4```H<,!OE$S"#X@,`H.$($9_E
M<^[_ZP`PH.$``%/C+0``"H0`&^41[O_K`$"@X1PP&^43,(/B`P"@X0SN_^L`
M,*#A`S"$X`(P@^(4,`OE%#`;Y0,`H.$C[O_K`#"@X1@P"^4<,!OE$S"#XA@`
M&^6L$)_EA"`;Y8+M_^N`,$OB&``;Y0,0H.$Y!`#K`#"@X0$`<^,*```*<#`;
MY0\Z`^(!"5/C!@``&H@P&^4``%/C`P``"A@`&^4!$*#CN/__ZP$``.H8`!OE
M[.W_ZQ@`&^6Z[?_K`#"@XQ@P"^4@`!OEVNW_ZP`PH.$<,`OE'#`;Y0``4^.Z
M__\:(``;Y>[M_^N$,!OE``!3XP$```J$`!OE^^W_ZQ#02^(0J)WHV/$``.#S
M``#D\P``#<"@X0#8+>D$L$SB#-!-XA@`"^48`!OEL_'_ZP`PH.$4,`OE%``;
MY8_Q_^L`,*#A$#`+Y8WR_^L`,*#A``!3XQ,```H8,!OE``!3XQ````H8,!OE
M`##3Y0``4^,,```*$``;Y3`0G^72[?_K`""@X1`P&^4#`%+A!0``&A@`&^4!
M$*#C?/__ZQ0`&^4`$*#C>?__ZPS02^(`J)WHG/,```W`H.$0V"WI!+!,X@S0
M3>(4$`OE``"@X_KM_^L`,*#A`#"3Y0,`H.%F[?_K`#"@X0,`H.$D[?_K`#"@
MX0`PD^4$0)/E``"@X^[M_^L`,*#A`#"3Y0,`H.%:[?_K`#"@X0,`H.$V[?_K
M`#"@X0`PT^7_,`/B&##$Y0``H./A[?_K`#"@X0`PD^4#`*#A3>W_ZP`PH.$#
M`*#A"^W_ZP`PH.$`,)/E!$"3Y0``H./5[?_K`#"@X0`PD^4#`*#A0>W_ZP`P
MH.$#`*#A(.W_ZP`PH.$`,)/E$#"3Y8,[H.&C.Z#A`SB@X2,XH.$:,,3E0S2@
MX1LPQ.4``*#CPNW_ZP`PH.$`,)/E`P"@X2[M_^L`,*#A`P"@X>SL_^L`,*#A
M`#"3Y01`D^4``*#CMNW_ZP`PH.$`,)/E`P"@X2+M_^L`,*#A`P"@X?@1G^4`
M(*#CE>W_ZP`PH.$<,(3E``"@XZGM_^L`,*#A`#"3Y0,`H.$5[?_K`#"@X0,`
MH.'3[/_K`#"@X0`PD^4$0)/E``"@XYWM_^L`,*#A`#"3Y0,`H.$)[?_K`#"@
MX0,`H.'?[/_K`#"@X0`PD^4@,(3E``"@XY'M_^L`,*#A`#"3Y0,`H.'][/_K
M`#"@X0,`H.&[[/_K`#"@X0`PD^4$,)/E'#`+Y0``H..$[?_K`#"@X0`PD^4#
M`*#A\.S_ZP`PH.$#`*#A4.W_ZP`PH.$`,)/E``!3XPT```H``*#C=^W_ZP`P
MH.$`,)/E`P"@X>/L_^L`,*#A`P"@X4/M_^L`,*#A`#"3Y6PPD^48,`OE`0``
MZ@`@H.,8(`OE&"`;Y1PP&^4D((/E``"@XV3M_^L`,*#A`#"3Y0,`H.'0[/_K
M`#"@X0,`H.&.[/_K`#"@X0`PD^4$()/E`#"@XR@P@N4``*#C5NW_ZP`PH.$`
M,)/E`P"@X<+L_^L`,*#A`P"@X8#L_^L`,*#A`#"3Y00@D^4`,*#C+#""Y0``
MH.-([?_K`#"@X0`PD^4#`*#AM.S_ZP`PH.$#`*#A<NS_ZP`PH.$`,)/E!$"3
MY0``H.,\[?_K`#"@X0`PD^4#`*#AJ.S_ZP`PH.$#`*#A*>W_ZP`PH.$`,)/E
M,#"$Y1#02^(0J)WH#/,```W`H.$`V"WI!+!,X@303>(0$`OE``"@XRCM_^L`
M,*#A`#"3Y0,`H.&4[/_K`#"@X0,`H.$`$.#CG^S_ZP``H.,>[?_K`#"@X0`P
MD^4#`*#ABNS_ZP`PH.$#`*#A"!"?Y0`@H.,D[?_K"*B=Z%3A```-P*#A`-@M
MZ02P3.(XT$WB,!`+Y0`PH.,8,`OE``"@XPKM_^L`,*#A`#"3Y0,`H.%V[/_K
M`#"@X0,`H.&+[/_K`""@X0$PH.,`,,+E0`:?Y1WN_^L`,*#A%#`+Y10P&^4`
M`%/C"```"A0P&^4`,-/E,0!3XP0``!H4,!OE`3"#X@`PT^4``%/C````"O7P
M_^L``*#C[>S_ZP`PH.$`,)/E`P"@X5GL_^L`,*#A`P"@X>`5G^4!(*#C"S"@
MXT?L_^L`,*#A+#`+Y2PP&^4``%/C:P``"BPP&^4,,)/E&#"3Y2@P"^4!,*#C
M'#`+Y4(``.H``*#CU>S_ZP`PH.$`,)/E`P"@X4'L_^L`,*#A`R"@X1PP&^4!
M,$/B`@"@X2@0&^4#(*#A`#"@XX#L_^L`,*#A)#`+Y20P&^4``%/C,P``"E0U
MG^4`()/E'#`;Y0,QH.$#,(+@`#"3Y40P"^4D,!OE`#"3Y0@PD^4!.P/B``!3
MXP0```HD,!OE`#"3Y0PPD^5`,`OE$```Z@``H..O[/_K`#"@X0`PD^4#`*#A
M&^S_ZP`PH.$#(*#A)#`;Y0`PD^4"`*#A`Q"@X0`@H.,",*#CM.S_ZP`PH.%`
M,`OE1``;Y4`0&^6C[/_K`#"@X0``4^,*```:&#`;Y0$P@^(8,`OE'#`;Y0$P
M@^(<,`OEG#2?Y0`@D^4<,!OE`@!3X;?__[J(-)_E`#"3Y0$@0^(8,!OE`P!2
MX18``!H!,*#C'#`+Y0X``.H``*#CA.S_ZP`PH.$`,)/E`P"@X?#K_^L`,*#A
M`P"@X2@0&^7=Z__K`#"@X2`P"^4<,!OE`3"#XAPP"^4H-)_E`""3Y1PP&^4"
M`%/AZ___N@``H.-P[/_K`#"@X0`PD^4#`*#AW.O_ZP`PH.$#`*#A^!.?Y0$@
MH.,%,*#CRNO_ZP`PH.$L,`OE+#`;Y0``4^,C```*``"@XU_L_^L`,*#A`#"3
MY0,`H.'+Z__K`#"@X0,@H.$L,!OE##"3Y0`PD^4"`*#A`Q"@X:0CG^6\Z__K
M+#`;Y0PPD^4`,)/E"#"3Y0$U`^(``%/C#0``"@``H.-)[/_K`#"@X0`PD^4#
M`*#AM>O_ZP`PH.$#(*#A+#`;Y0PPD^4`,)/E`@"@X0,0H.$'[/_K``"@XSOL
M_^L`,*#A`#"3Y0,`H.&GZ__K`#"@X0,`H.$L$Y_E`2"@XP4PH..5Z__K`#"@
MX2PP"^4L,!OE``!3XRH```H`,*#C$#`+Y00#G^5'[?_K`#"@X1`P"^40,!OE
M``!3XP\```H``*#C(>S_ZP`PH.$`,)/E`P"@X8WK_^L`,*#A`R"@X2PP&^4,
M,)/E`#"3Y0(`H.$#$*#A$"`;Y7[K_^L1``#J``"@XQ'L_^L`,*#A`#"3Y0,`
MH.%]Z__K`#"@X0,0H.$L,!OE##"3Y0`@D^5H,I_E`#"3Y0`PD^4!`*#A`A"@
MX0,@H.%P[/_K``"@X__K_^L`,*#A`#"3Y0,`H.%KZ__K`#"@X0,`H.&`Z__K
M`""@X0`PH.,`,,+E``"@X_/K_^L`,*#A`#"3Y0,`H.%?Z__K`#"@X0,`H.'U
MZ__K`""@X0`PH.,`,(+E!`*?Y0;M_^L`(*#A_#&?Y0`@@^7T,9_E`#"3Y0``
M4^-4```:R#&?Y0`PD^4#`*#A&_O_ZP`@H.'0,9_E`""#Y2PP&^4,,)/E`#"3
MY0@PD^4!.P/B``!3XP4```HL,!OE##"3Y0`PD^4,,)/E/#`+Y1$``.H``*#C
MRNO_ZP`PH.$`,)/E`P"@X3;K_^L`,*#A`R"@X2PP&^4,,)/E`#"3Y0(`H.$#
M$*#A`""@XP(PH./.Z__K`#"@X3PP"^4P,9_E`#"3Y3P`&^4#$*#A6^O_ZP`P
MH.$<,`OE%#&?Y0`PD^4`,)/E.#`+Y2PP&^4,,)/E`#"3Y0@PD^4!.P/B``!3
MXP4```HL,!OE##"3Y0`PD^4,,)/E-#`+Y1$``.H``*#CH.O_ZP`PH.$`,)/E
M`P"@X0SK_^L`,*#A`R"@X2PP&^4,,)/E`#"3Y0(`H.$#$*#A`""@XP(PH..D
MZ__K`#"@X30P"^6H`)_E.!`;Y30@&^4<,!OE:NO_ZY`PG^4`,)/E`P"@X7L?
MH.,!$('BO.K_ZP`PH.$<,`OE'#`;Y0``4^,/```*'#`;Y1$`4^,,```*'#`;
MY0$`<^,)```*,#"?Y0`PD^4`()/E0#"?Y0`PD^5``)_E`A"@X0,@H.$<,!OE
M3^O_ZPS02^(`J)WHY/$``.SS``"@X@$`G.(!`/3S``#X\P```/0``,CQ``"\
M\0``F.(!``3T```T]```#<"@X0#8+>D$L$SB"-!-X@``H.-<Z__K`#"@X0`P
MD^4#`*#AR.K_ZP`PH.$#`*#AKNO_ZP``H.-3Z__K`#"@X0`PD^4#`*#AO^K_
MZP`PH.$#(*#A)#"?Y0`PC>4`,*#C!#"-Y0(`H.$4$)_E%""?Y0@PG^7>ZO_K
M#-!+X@"HG>@,\P``A/0```SE```-P*#A`-@MZ02P3.(@T$WB&``+Y1P0"^4@
M(`OE&#!+XAP@2^(@P$OB`P"@X0(0H.$,(*#A*^O_ZY@#G^68$Y_EE".?Y?``
M`.L``*#CI.K_ZP`PH.$`,-/E``!3XQD``!J<ZO_K`""@X7`SG^4`((/E:#.?
MY0`PD^4``%/C`0``&@$`H.,IZ__K4#.?Y0`PD^4#`*#AMNK_ZP``H.,7Z__K
M`#"@X0`PD^4#`*#A@^K_ZP`PH.$#`*#A\NK_ZP`@H.$`,*#C`##"Y0``H.,+
MZ__K`#"@X0`PD^4#`*#A=^K_ZP`PH.$#`*#A!^O_ZP`PH.$#(*#A`##2Y0(P
M@^/_,`/B`##"Y0``H./\ZO_K`#"@X0`PD^4#`*#A:.K_ZP`PH.$#`*#A^.K_
MZP`PH.$#(*#A`##2Y0$P@^/_,`/B`##"Y1@P&^4%,(/BD#$`[@J!"^T``%/C
M`P``JIJ!G^T*D1OM@!$![@J1"^T*@1OMB!$`[I:!G^T0\='N`#"@TP$PH,/_
M,`/B`3`CXO\P`^(``%/C`0``&D@"G^6WZO_K&#`;Y04P@^(#,:#A`P"@X;CJ
M_^L`,*#A`R"@X2@RG^4`((/E(#*?Y0`@D^4<,!OE`#"3Y0`P@N4,,I_E`#"3
MY00@@^($,I_E`#""Y?@QG^4`,)/E"""#XO0QG^4`,(+E\"&?Y0,PH.,`,(+E
MV#&?Y0`@D^7<,9_E`#"3Y0,QH.$#((+@T#&?Y0`P@N7$,9_E`#"3Y0$@@^*X
M,9_E`""#Y0$PH.,0,`OE$@``ZI@QG^4`$)/EG#&?Y0`@D^40,!OE`S""X`$P
M8^(#,:#A`#!CX@,0@>`<(!OE$#`;Y0,QH.$#,(+@`#"3Y0`P@>40,!OE`3"#
MXA`P"^48(!OE$#`;Y0(`4^'H__^Z/#&?Y0`0D^48(!OE/#&?Y0`PD^4#,(+@
M`3!CX@,QH.$`,&/B`R"!X``PH.,`,(+E!#&?Y0`0D^48(!OE##&?Y0`PD^4#
M,(+@`2!#XO`PG^4`P)/E`#"@XP`PC>4!`*#A\!"?Y0PPH.&XZ?_K`#"@X10P
M"^44,!OE``!3XP4``!JT,)_E`#"3Y0,`H.'0Z?_K`#"@X10P"^6<,)_E`#"3
MY0,`H.$MZO_KK`"?Y8GK_^L`,*#A``!3XQ```!J<,)_E`#"3Y0``4^,$```:
MD`"?Y8#K_^L`(*#A@#"?Y0`@@^5X,)_E`#"3Y0``4^,#```*:#"?Y0`PD^4#
M`*#A+/S_ZS0PG^4`,)/E`P"@X8SI_^O?Z?_K%#`;Y0,`H.$,T$OB`*B=Z```
M\$$`````___/00``@/^XEP``7)8``)3B`0!TT@$`H.(!`)ST``"L]```G.(!
M`*#T``#0ZP``]/$``)CB`0"\\0``'#"?Y1S`G^4$X"WE`S"/X`S@D^`,,),7
M#C"@`03@G>2+Z?_JB.```%`!```.\*#A\$<MZ0"@H.$!@*#A`G"@X420G^5+
MZ?_K0#"?Y4!0G^4#,&G@0V&PX050C^#PA[T(`$"@XPDPA>`*`*#A"!"@X0<@
MH.$/X*#A!/&3YP%`A.($`%;A]O__&O"'O>C\_O___/[__SS@```!(*#A`!"@
MX0,`H.->Z?_J`2"@X0`0H.$#`*#CD.G_ZB@@G^4$,!+E`0!SXQ!`+>D0@+T(
M!$!"X@_@H.$#\*#A!#`TY0$`<^/Z__\:$("]Z`30`0`$X"WE!/"=Y`3@+>4I
MZO_K!/"=Y`$``@!P97)L>'-I+F,```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,
M;V%D97(`+W!R;V,O<V5L9B]E>&4``"\````Z````+W!R;V,O)6DO)7,`97AE
M`%!!4E]414U0`````%!!4E]04D]'3D%-10`````N````)7,E<R5S``!005)?
M24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'
M````4$%27T-!0TA%````4$%27T%21T,`````4$%27T%21U9?,```4$%27T=,
M3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(`
M`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!
M3CT``#$```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`````!,
M1%],24)205)97U!!5$@`3$E"4$%42`!,24)205)97U!!5$@`````4$%42```
M``!$64Q$7TQ)0E)!4EE?4$%42`````````#(\@``V/(``.#R``#P\@``^/(`
M``SS``!54T52`````%5315).04U%`````"CS```P\P``#/,``%1-4$1)4@``
M5$5-4$1)4@!414U0`````%1-4`!D\@``2/,``%#S``!8\P``8/,```SS``!#
M.EQ414U0`"]T;7``````?/,``(3S``#8\0``#/,``'!A<BT`````4UE35$5-
M```E<R5S)7,E<P`````E<R5S8V%C:&4M)7,E<P``)3`R>``````E<R5S=&5M
M<"TE=25S````+BX``"5S+R5S````05)'5@`````8````<&5R;``````P````
M)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I
M+@H`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@=&5M<&]R87)Y('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H```!);G1E<FYA
M;',Z.E!!4CHZ0D]/5``````M90``+2T``'!A<BYP;```(R$O=7-R+V)I;B]P
M97)L"@IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B
M?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*
M<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T
M('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T
M<FEC=#L*"B-L:6YE(#$U.0H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`
M=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E
M<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64[
M"B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@<FUD:7(@
M)'1O<&1I<CL*"B`@("!I9B`H+60@)'!A<E]T96UP*2!["B`@("`@("`@(R!3
M;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D
M:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O
M;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@
M("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN
M('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L
M;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B
M>2!T:&ES('!R;V-E<W,N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@
M("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@("`@
M("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("`C($)E8V%U<V4@
M=&AE('!A<E]T96UP(&1I<F5C=&]R>2!I<R!G;VEN9R!T;R!B92!D96QE=&5D
M(&EN(&$*("`@("`@("`C(&)A8VMG<F]U;F0@<')O8V5S<RP@=&AE('!A<F5N
M="!P<F]C97-S(&ED(&UA>2!B92!R975S960@8F5F;W)E('1H90H@("`@("`@
M(",@8F%C:V=R;W5N9"!P<F]C97-S(&-O;7!L971E<RX@(%1O(&5N<W5R92!T
M:&%T('1H92!T96UP;W)A<GD*("`@("`@("`C(&1I<F5C=&]R>2!D;V5S(&YO
M="!G970@<F5U<V5D('=H:6QE(&ET(&ES(&)E:6YG(&1E;&5T960L('1R>2!T
M;PH@("`@("`@(",@<F5N86UE(&ET('1O(&$@;F%M92!T:&%T(&ES(')E;&%T
M960@=&\@=&AE('1E;7!O<F%R>2!S8W)I<'0@9FEL92X*"B`@("`@("`@;7D@
M)'1M<&YA;64@/2`H1FEL93HZ4W!E8RT^<W!L:71P871H*"1T;7`M/F9I;&5N
M86UE*2E;,ET[(",@9FEL96YA;64*("`@("`@("`D=&UP;F%M92`]?B!S+UPN
M6UXN72HD+RYD:7(O.PH@("`@("`@(&UY("1N97=$:7(@/2!&:6QE.CI3<&5C
M+3YC871P871H*`H@("`@("`@("`@("`H1FEL93HZ4W!E8RT^<W!L:71P871H
M*"1P87)?=&5M<"DI6S`N+C%=+"`D=&UP;F%M92D["B`@("`@("`@:68@*')E
M;F%M92`D<&%R7W1E;7`L("1N97=$:7(I('L*("`@("`@("`@("`@;W5T<R@B
M4F5N86UE9"`D<&%R7W1E;7`@=&\@)&YE=T1I<B(I.PH@("`@("`@("`@("`D
M<&%R7W1E;7`@/2`D;F5W1&ER.PH@("`@("`@('T*"B`@("`@("`@:68@*"1>
M3R`]?B!M+W=I;C,R+VDI('L*("`@("`@("`@("`@<')I;G0@)'1M<"`B"CIL
M;V]P"G)M9&ER("]Q("]S(%PB)'!A<E]T96UP7"(*:68@97AI<W0@7"(D<&%R
M7W1E;7!<(B!G;W1O(&QO;W`*<FUD:7(@7"(D=&]P9&ER7"(*<FT@7"(B("X@
M)'1M<"T^9FEL96YA;64@+B`B7"(*(CL*("`@("`@("`@("`@8VQO<V4@)'1M
M<#L*("`@("`@("`@("`@;7D@)'!R;V,["B`@("`@("`@("`@(%=I;C,R.CI0
M<F]C97-S.CI#<F5A=&4H"B`@("`@("`@("`@("`@("`D<')O8RP@)$5.5GM#
M3TU34$5#?2P*("`@("`@("`@("`@("`@("(D14Y6>T-/35-014-]("]C(%PB
M(B`N("1T;7`M/F9I;&5N86UE("X@(EPB(#YN=6P@,CYN=6P@(BP*("`@("`@
M("`@("`@("`@(#$L($Y/4DU!3%]04DE/4DE465]#3$%34RP@(BXB"B`@("`@
M("`@("`@("D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<')I;G0@
M)'1M<"`B(R$O8FEN+W-H"G=H:6QE(%L@+60@)R1P87)?=&5M<"<@73L@9&\*
M("`@<FT@+7)F("<D<&%R7W1E;7`G"F1O;F4*<FUD:7(@)R1T;W!D:7(G"G)M
M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO
M9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@("`@("!M>2`D8VUD(#T@
M)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@
M("`@("`@8VQO<V4@)'1M<#L*("`@("`@("`@("`@<WES=&5M*"1C;60I.PH@
M("`@("`@('T*("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P
M<F]C97-S('1O('!E<F9O<FT@8VQE86YU<"DI.PH@("`@?0I]('T*"D)%1TE.
M('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT
M97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV
M*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%2
M7T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D
M7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6
M>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*
M("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@
M?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R
M;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@
M("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P
M<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C
M:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY
M("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T
M('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L
M("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY
M("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U
M9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*
M("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@
M(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE
M(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F
M+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@
M;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I
M(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E
M860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@
M(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I
M.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN
M;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*
M("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C
M:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE
M;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@
M)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@
M7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[
M4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")3
M2$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO
M9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@
M("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@
M("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@
M("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@
M("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C
M<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE
M+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS
M=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@
M("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@
M("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O
M<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@
M;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D
M:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L
M971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@
M("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[
M4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@
M("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P
M<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D
M9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`]
M(%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@
M("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I
M.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69]
M.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$[
M"B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N
M("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F
M86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD[
M"@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C
M(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U
M:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q
M=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@
M;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET
M:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F
M('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T
M(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.
M0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@
M("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@
M9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I
M;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I
M<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U
M<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@
M=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I
M;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PH*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?
M1$5"54=].PH*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL
M960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T
M87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H
M:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L
M:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@
M('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*("`@("`@("!V
M("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("!M>2!`861D7W1O7VEN8SL*("`@
M('=H:6QE("A`05)'5BD@>PH@("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@(&EF("@D,2!E
M<2`G22<I('L*("`@("`@("`@("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@
M("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@
M("`@979A;"`B=7-E("0R(CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q
M(&5Q("=!)RD@>PH@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#([
M"B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@
M("`@("`@)&]U="`]("0R.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@
M97$@)V(G*2!["B`@("`@("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@
M("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@("`@("`@
M)&)U;F1L92`]("=A;&PG.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@
M97$@)W$G*2!["B`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@?0H@
M("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@;W!E;B`D
M;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z
M("0A(CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@
M("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@('T*"B`@("`@
M("`@<VAI9G0H0$%21U8I.PH*("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T
M7V-M9'LD,7TI('L*("`@("`@("`@("`@9&5L971E("1%3E9[)U!!4E]414U0
M)WT["B`@("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@(')E<75I
M<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B
M?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@("`@("`@97AI=#L*("`@("`@
M("!]"B`@("!]"@H@("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0H*
M(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/
M=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@
M>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF
M("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*
M("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"@H@("`@;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD
M969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R
M(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@
M("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A
M<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@
M("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G
M345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@
M("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@
M("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S
M('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R
M*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D
M<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R
M(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP
M,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@
M24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@
M24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D
M:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D
M9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L
M(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@
M*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<
M0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY
M*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O
M<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O
M7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C
M*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H
M)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H
M("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N
M9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@
M("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C
M('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@
M*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@
M("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN
M:71?:6YC*"D["B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@
M(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@
M;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$
M4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE
M("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@
M("!I9B`H)$-O;F9I9WM?9&5L:6U](&5Q("=<7"<I('L@<WM<7'U[+WUG(&9O
M<B!`:6YC('T*"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI
M)"\@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I
M;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R
M:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@("`@("`@("!F
M;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@("`@(&EF("@D
M;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@
M("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@("`@("`@("!L
M87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@
M("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@
M("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`H
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R
M:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL
M92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@
M("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B
M*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@
M("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@
M(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@
M("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!O
M<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE
M.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@
M("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@("`@("`@("!C
M;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@
M("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@("`C($1O(&YO
M="!L970@6%-,;V%D97(@<&EC:R!U<"!A=71O+RH@9G)O;2!E;G9I<F]N;65N
M=`H@("`@("`@("`@("`@("`@)&-O;G1E;G0@/7X@<R]G;W1O("MR971R>2`K
M=6YL97-S("LN*B]G;W1O(')E=')Y.R\*("`@("`@("`@("`@("`@("`@("!I
M9B!L8R@D;F%M92D@97$@;&,H(EA33&]A9&5R+G!M(BD["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D[
M"B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@
M)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@
M("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@("`@("`@
M(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N
M="DL("1N86UE"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R
M:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@
M("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*("`@(",@
M?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T
M<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF
M("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L
M(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@
M("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E
M<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@
M5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N
M,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@
M("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@
M("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A
M;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@("`@("!B
M:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F
M:"D["B`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X
M+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N
M/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@("1C86-H
M95]N86UE("X](")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE
M*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T
M:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@
M("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]
M?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT
M;R!005(@9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE
M9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO
M=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#
M86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[
M)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@
M("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H
M:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P
M96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@
M0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-
M4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S
M:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M
M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X
M="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE
M;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@
M7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_
M.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@
M*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@
M("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@("!]>#L*
M("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@
M("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!
M4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D
M9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ
M92@I*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M
M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N
M86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@
M("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B
M('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN
M<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"
M?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]
M?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@
M"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M
M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D
M;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@[
M"B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&
M24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*
M("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*
M("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@
M(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@
M0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@
M(')E<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@<F5Q
M=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@
M<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q
M=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E
M<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z.EII
M<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@
M("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@979A
M;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R
M.CI0<F]C97-S('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@
M?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!]
M.PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@
M;7EL9'(O;6MT;7!D:7(N8PIS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@
M('T*"B`@("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[
M)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I
M*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@
M("`@(&YE>'0@=6YL97-S("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*
M("`@("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E
M=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT[
M"@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2![
M"B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@
M("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@
M("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I
M<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@
M("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM0
M05)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY
M72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE
M*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@
M<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F
M(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU
M."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*
M("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@
M("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE
M=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@
M("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N
M9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L
M('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@
M("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO
M;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F
M:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T
M>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@
M("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]
M"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@
M;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@
M("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY
M("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*
M"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M
M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I
M;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E
M9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O
M<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D
M92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*<W5B(%]S
M971?<')O9VYA;64@>PH@("`@:68@*"1%3E9[4$%27U!23T=.04U%?2!A;F0@
M)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G
M;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R
M(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@
M("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@
M("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I
M9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@
M("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L
M:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@
M("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG
M>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@
M("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]
M"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B
M+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@
M+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@
M("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I
M9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!]
M(&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@
M("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!
M0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!4
M14U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@
M/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%
M3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6
M>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%
M04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL
M(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!
M3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@
M?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@
M*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]
M"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U
M8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@
M("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA
M:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN
M.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R
M.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N
M)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE
M(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O
M("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@
M/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D
M.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,3<*"E]?14Y$7U\*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````/____\`````_____P```````````0````$````!````
MOP(```$```#*`@```0```-0"```!````$@,```$````Z!```#````."5```-
M````7/$```0```!(@0``!0````R,```&````K(0```H```#?!0``"P```!``
M```5``````````,````$T0$``@```'`"```4````$0```!<```!PDP``$0``
M`%B3```2````&````!,````(````_O__;]B2``#___]O`@```/#__V_LD0``
M````````````````````````````````````````````````````````````
M````%-`!````````````])4``/25``#TE0``])4``/25``#TE0``])4``/25
M``#TE0``])4``/25``#TE0``])4``/25``#TE0``])4``/25``#TE0``])4`
M`/25``#TE0``])4``/25``#TE0``])4``/25``#TE0``])4``/25``#TE0``
M])4``/25``#TE0``])4``/25``#TE0``])4``/25``#TE0``])4``/25``#T
ME0``])4``/25``#TE0``])4``/25``#TE0``])4``/25``#TE0``])4``/25
M``#TE0``])4``/25``#TE0``])4``/25``#TE0``])4``/25``#TE0``])4`
M`/25``#TE0``])4``/25``#TE0``])4``/25``#TE0``])4``/25``#TE0``
M])4``/25``#TE0```````````````````````*3Q``"H\0``_____Z3T``"W
M6@````````!'0T,Z("A'3E4I(#0N,BXS("A$96)I86X@-"XR+C,M,BD``$=#
M0SH@*$=.52D@-"XR+C,@*$1E8FEA;B`T+C(N,RTR*0``1T-#.B`H1&5B:6%N
M(#0N,RXP+3,I(#0N,RXQ(#(P,#@P-#`Q("AP<F5R96QE87-E*0``1T-#.B`H
M1&5B:6%N(#0N,RXP+3,I(#0N,RXQ(#(P,#@P-#`Q("AP<F5R96QE87-E*0``
M1T-#.B`H1&5B:6%N(#0N,RXP+3,I(#0N,RXQ(#(P,#@P-#`Q("AP<F5R96QE
M87-E*0``1T-#.B`H1TY5*2`T+C(N,R`H1&5B:6%N(#0N,BXS+3(I``!'0T,Z
M("A'3E4I(#0N,BXS("A$96)I86X@-"XR+C,M,BD``$=#0SH@*$=.52D@-"XR
M+C,@*$1E8FEA;B`T+C(N,RTR*0``1T-#.B`H1TY5*2`T+C(N,R`H1&5B:6%N
M(#0N,BXS+3(I``!'0T,Z("A$96)I86X@-"XS+C`M,RD@-"XS+C$@,C`P.#`T
M,#$@*'!R97)E;&5A<V4I``!'0T,Z("A'3E4I(#0N,BXS("A$96)I86X@-"XR
M+C,M,BD`00\```!A96%B:0`!!0`````N<VAS=')T86(`+FEN=&5R<``N;F]T
M92Y!0DDM=&%G`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`
M+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`
M+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD
M>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T
M97,````````````````````````````````````````````````````````+
M`````0````(````4@0``%`$``!,```````````````$`````````$P````<`
M```"````*($``"@!```@```````````````$`````````"$````%`````@``
M`$B!``!(`0``9`,```0`````````!`````0````G````"P````(```"LA```
MK`0``&`'```%`````0````0````0````+P````,````"````#(P```P,``#?
M!0`````````````!`````````#<```#___]O`@```.R1``#L$0``[`````0`
M`````````@````(```!$````_O__;P(```#8D@``V!(``(`````%`````@``
M``0`````````4P````D````"````6),``%@3```8````!``````````$````
M"````%P````)`````@```'"3``!P$P``<`(```0````+````!`````@```!E
M`````0````8```#@E0``X!4``!0```````````````0`````````8`````$`
M```&````])4``/05``"\`P`````````````$````!````&L````!````!@``
M`+"9``"P&0``K%<`````````````!`````````!Q`````0````8```!<\0``
M7'$```P```````````````0`````````=P````$````"````:/$``&AQ``#\
M70`````````````$`````````'\````!`````@```&1/`0!DSP``!```````
M````````!`````````")`````0````,`````T`$``-````@`````````````
M``0`````````D`````$````#````"-`!``C0```(```````````````$````
M`````)<````!`````P```!#0`0`0T```!```````````````!`````````"<
M````!@````,````4T`$`%-```/`````%``````````0````(````I0````$`
M```#````!-$!``31``!(`0`````````````$````!````*H````!`````P``
M`$S2`0!,T@``)```````````````!`````````"P````"`````,```!PT@$`
M<-(``#00``````````````0`````````M0````$``````````````'#2``#!
M`0`````````````!`````````+X````#``!P```````````QU```$```````
M`````````0`````````!`````P``````````````0=0``,X`````````````
M``$``````````0```/25```````````+``0````$E@``````````"P`!````
3")8```````````L``"1A`"1D````
